<?php
/*
Plugin Name: Burnhambox - Metz Slider
Plugin URI: http://www.burnhambox.com
Description: Metz Slider.
Version: 1.1
Author: Burnhambox
Author URI: http://www.burnhambox.com
License: GNU
*/

/* SLIDER */
function metz_create_slider_posttype() {

	$labels = array(
		'add_new_item' => 'Add New Slide'
	);

	$args = array(
		'labels' => $labels,
		'public' => false,
		'show_ui' => true,
		'menu_icon' => 'dashicons-images-alt',
		'capability_type' => 'page',
		'rewrite' => array( 'slider-loc', 'post_tag' ),
		'label'  => 'Metz Slider',
		'supports' => array( 'title', 'custom-fields', 'thumbnail', 'page-attributes' ),
	);

	register_post_type( 'slider', $args );

}

add_action( 'init', 'metz_create_slider_posttype' );

//

function metz_create_slider_location_tax() {

	register_taxonomy( 'slider-loc', 'slider', array(
			'label' => 'Slider Location',
			'public' => false,
			'show_ui' => true,
			'show_admin_column' => true,
			'rewrite' => false
		)
	);

}

add_action( 'init', 'metz_create_slider_location_tax' );

//

function metz_set_default_slidermeta( $post_ID ) {

	add_post_meta( $post_ID, 'Metz-Slider-URL', 'http://', true );
	add_post_meta( $post_ID, 'Metz-Slider-Button', 'DISCOVER NOW', true );
	add_post_meta( $post_ID, 'Metz-Slider-Target', '_self', true );
	add_post_meta( $post_ID, 'Metz-Slider-Caption', 'Lorem ipsum dolor sit amet.', true );

	return $post_ID;

}

add_action( 'wp_insert_post', 'metz_set_default_slidermeta' );

//

function metz_slider_shortcode( $atts = null ) {

	global $add_my_script, $ss_atts;
	$add_my_script = true;
	$ss_atts = shortcode_atts(
		array(
			'location' => '',
			'limit' => -1,
		), $atts, 'metzslider'
	);

	$args = array(
		'post_type' => 'slider',
		'posts_per_page' => $ss_atts['limit'],
		'orderby' => 'menu_order',
		'order' => 'ASC'
	);

	if ( $ss_atts['location'] != '' ) {

		$args['tax_query'] = array(
			array( 'taxonomy' => 'slider-loc', 'field' => 'slug', 'terms' => $ss_atts['location'] )
		);

	}

	$the_query = new WP_Query( $args );
	$slides = array();

	$pager_padding = 20;
	$brnhmbx_opt_bxControls = get_theme_mod( 'brnhmbx_opt_bxControls_Main', 'arrow' );
	$brnhmbx_sliderHeight = get_theme_mod( 'brnhmbx_sliderHeight', 500 );

	if ( ( $brnhmbx_opt_bxControls == 'bullet' || $brnhmbx_opt_bxControls == 'both' ) ) {

		$pager_padding = 40;

	}

	if ( $the_query->have_posts() ) {

		while ( $the_query->have_posts() ) {

			$the_query->the_post();
			$img_path = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'slider-image' );
			$url = get_post_meta( get_the_ID(), 'Metz-Slider-URL', true );
			$caption_text = get_post_meta( get_the_ID(), 'Metz-Slider-Caption', true );
			$button_text = get_post_meta( get_the_ID(), 'Metz-Slider-Button', true );
			$button_target = get_post_meta( get_the_ID(), 'Metz-Slider-Target', true );
			$padding_button = 'padding-top: 11px;';
			$button = '';
			$caption = '';
			$header = '';
			$padding_if_not_empty = '';
			$padding_caption = '';
			$slide_image = '';

			if ( $img_path ) {

				$slide_image = $img_path[0];

			} else {

				$slide_image = get_template_directory_uri() . '/css/images/image-placeholder.jpg';

			}

			if ( get_the_title() ) {

				$header = '<div class="playfair slider-header">' . esc_attr( get_the_title() ) . '</div>';
				$padding_caption = 'padding-top: 20px;';

			}

			if ( $caption_text ) {

				$caption = '<div class="playfair fs16 slider-caption" style="' . esc_attr( $padding_caption ) . '">' . esc_attr( $caption_text ) . '</div>';
			}

			if ( $header || $caption ) {

				$padding_button = 'padding-top: 35px;';

			}

			if ($url != '' && $url != 'http://') {

				$button = '<div class="bButton montserrat slider-button" style="' . esc_attr( $padding_button ) . ' line-height: 30px;"><a href="' . esc_url( $url ) . '" target="' . esc_attr( $button_target ) . '">' . esc_attr( $button_text ) . '</a></div>';
			}

			if ( $button || $caption || $header ) {

				$padding_if_not_empty = 'padding: 35px 80px 35px 80px; ';

			}

			$slides[] = '
			<li><div class="slide-container" style="background-image: url(' . esc_url( $slide_image ) . '); height: ' . esc_attr( $brnhmbx_sliderHeight ) . 'px;">
				<div class="slide-info-outer">
                    <div class="slide-info">
                        <div class="slide-info-inner">
							<div class="slide-text" style="' . esc_attr( $padding_if_not_empty ) . '">' . wp_kses_post( $header ) . wp_kses_post( $caption ) . wp_kses_post( $button ) . '</div>
                        </div>
                    </div>
                </div>
			</div></li>';

		}

	}

	wp_reset_query();

	return '<div class="metz-slider-container" style="padding-bottom: ' . esc_attr( $pager_padding ) . 'px;"><ul class="bxslider-main" style="overflow: hidden; height: ' . esc_attr( $brnhmbx_sliderHeight ) . 'px;">' . implode( '', $slides ) . '</ul></div>';
}

add_shortcode( 'metzslider', 'metz_slider_shortcode' );
/* */
?>
