<?php
/* Customize Appearance Options */
function metz_customizeAppearance( $wp_customize ) {

	/* Custom Text Area Control in Customizer */
	class metz_customTextAreaControl extends WP_Customize_Control {

		public $type = 'textarea';

		public function render_content() { ?>
			<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<textarea rows="8" style="width: 100%; resize: none;" <?php esc_url( $this->link() ); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
			<?php
		}

	}
	/* */

	/* Font Selector */
	class metz_font_selector extends WP_Customize_Control {

			public $type = 'select';

			public function render_content() { ?>

				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<span class="customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span>
					<select <?php $this->link(); ?>>
                    	<?php
						foreach ( metz_font_labels() as $key => $val ) {
							$add_underscore = str_replace( ' ', '_', $key ); ?>
							<option value="<?php echo esc_attr( $add_underscore ); ?>" <?php if( $this->value() == $add_underscore ) echo 'selected="selected"'; ?>><?php echo esc_attr( $key ); ?></option>
						<?php } ?>
					</select>
				</label>

			<?php }

	}
	/* */

	/* Sanitizers */
		function metz_get_font_list() {
			$font_list = array();
			foreach ( metz_font_labels() as $key => $val ) {
				$add_underscore = str_replace( ' ', '_', $key );
				$font_list[] = esc_attr( $add_underscore );
			}
			return $font_list;
		}

		function metz_sanitize_select( $input ) {
			$current_font_list = metz_get_font_list();
	    return ( in_array( $input, $current_font_list ) ? $input : 'null' );
		}

		function metz_sanitize_file( $file, $setting ) {
	    $mimes = array(
	        'jpg|jpeg|jpe' => 'image/jpeg',
	        'gif'          => 'image/gif',
	        'png'          => 'image/png'
	    );
	    $file_ext = wp_check_filetype( $file, $mimes );
	    return ( $file_ext['ext'] ? $file : $setting->default );
	  }

		function metz_sanitize_null( $input ) {
			return 0;
		}

		function metz_sanitize_let_html( $input ) {
			return force_balance_tags( wp_kses_post( $input ) );
		}

		function metz_sanitize_checkbox( $input ) {
			if ( $input == 1 ) {
				return 1;
			} else {
				return '';
			}
		}

		function metz_sanitize_choices( $input, $setting ) {
			global $wp_customize;
			$control = $wp_customize->get_control( $setting->id );
			if ( array_key_exists( $input, $control->choices ) ) {
				return $input;
			} else {
				return $setting->default;
			}
		}

		function metz_sanitize_integer( $input ) {
			if( is_numeric( $input ) ) {
				return intval( $input );
			}
		}
		/* */

		/* Allowed HTML */
		$metz_allowed_html = array(
				'a' => array(
					'href' => array(),
					'target' => array(),
			),
			'span' => array(
				'class' => array(),
			),
			'br' => array(),
			'em' => array(),
			'strong' => array(),
			'hr' => array(),
		);
		/* */

	// Sections

	$wp_customize->add_section( 'brnhmbx_sectionGeneral', array(
		'title' => esc_html__( '1. General Settings', 'metz' ),
		'priority' => 0,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionBackground', array(
		'title' => esc_html__( '2. Site Background', 'metz' ),
		'priority' => 5,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionHeader', array(
		'title' => esc_html__( '3. Header', 'metz' ),
		'priority' => 10,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionSlider', array(
		'title' => esc_html__( '4. Slider Settings', 'metz' ),
		'priority' => 15,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionHomeWidgets', array(
		'title' => esc_html__( '5. Sidebar, Upper & Home Widgets', 'metz' ),
		'priority' => 20,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionLayout', array(
		'title' => esc_html__( '6. Layout Options', 'metz' ),
		'priority' => 25,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostColors', array(
		'title' => esc_html__( '7. Post & Page Colors', 'metz' ),
		'priority' => 30,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatStandard', array(
		'title' => esc_html__( '8. Post Format: Standard', 'metz' ),
		'priority' => 35,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatGallery', array(
		'title' => esc_html__( '9. Post Format: Gallery', 'metz' ),
		'priority' => 40,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatVideo', array(
		'title' => esc_html__( '10. Post Format: Video', 'metz' ),
		'priority' => 45,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionRP', array(
		'title' => esc_html__( '11. Related Posts', 'metz' ),
		'priority' => 50,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPC', array(
		'title' => esc_html__( '12. Post & Page Comments', 'metz' ),
		'priority' => 55,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionFooter', array(
		'title' => esc_html__( '13. Footer', 'metz' ),
		'priority' => 60,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionFooterWidgets', array(
		'title' => esc_html__( '14. Footer Widgets', 'metz' ),
		'priority' => 65,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionShowHide', array(
		'title' => esc_html__( '15. Show/Hide Elements', 'metz' ),
		'priority' => 70,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionSocial', array(
		'title' => esc_html__( '16. Social Accounts', 'metz' ),
		'description' => wp_kses( __( 'Write the entire URL addresses.<br>Leave blank if not preferred.', 'metz' ), $metz_allowed_html ),
		'priority' => 75,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionGoogleMaps', array(
		'title' => esc_html__( '17. Google Maps', 'metz' ),
		'priority' => 80,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionTranslation', array(
		'title' => esc_html__( '18. Translation', 'metz' ),
		'priority' => 85,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionCSS', array(
		'title' => esc_html__( '19. Custom CSS', 'metz' ),
		'description' => esc_html__( 'Write your CSS code to override styles.', 'metz' ),
		'priority' => 90,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionBanner', array(
		'title' => esc_html__( '20. Banner Management', 'metz' ),
		'priority' => 95,
	) );

	// Settings
	$wp_customize->add_setting( 'brnhmbx_upload_Favicon', array( 'sanitize_callback' => 'metz_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_Uppercase', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_productPerPage', array( 'default' => 6, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'metz2017_font_primary', array( 'default' => 'Playfair_Display', 'sanitize_callback' => 'metz_sanitize_select' ) );
	$wp_customize->add_setting( 'metz2017_font_secondary', array( 'default' => 'Arial', 'sanitize_callback' => 'metz_sanitize_select' ) );
	$wp_customize->add_setting( 'brnhmbx_imageWidth', array( 'default' => 1080, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_imageHeight', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Background', array( 'default' => '#f0eeee', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_Background', array( 'sanitize_callback' => 'metz_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_centerBackground', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_repeatBackground', array( 'default' => 'no-repeat', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_text_Logo', array( 'default' => wp_title(), 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Logo', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_Logo', array( 'sanitize_callback' => 'metz_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_StickyLogo', array( 'sanitize_callback' => 'metz_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_LogoRetina', array( 'sanitize_callback' => 'metz_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_logoPaddingBottom', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_logoPaddingTop', array( 'default' => 40, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_MenuPos', array( 'default' => 'logo-top', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_MenuWidth', array( 'default' => '1080', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_stickyHeader', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_triggerSticky', array( 'default' => 300, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'metz_slicknav_apl', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_useFAIcon', array( 'default' => 'fa-diamond', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_StickyLogo', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderSocial', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderMenu', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ExtraSidebar_Archive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ExtraSidebar_Page', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ExtraSidebar_Post', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_explanation_2', array( 'default' => '0', 'sanitize_callback' => 'metz_sanitize_null' ) );
	$wp_customize->add_setting( 'brnhmbx_headerWidgetsCol', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderWidgets', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderWidgetsFront', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderWidgetsPage', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderWidgetsPost', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderWidgetsArchive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_explanation_3', array( 'default' => '0', 'sanitize_callback' => 'metz_sanitize_null' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HomeWidgets', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_use3ColHome', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HomeWidgetsFront', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_explanation_4', array( 'default' => '0', 'sanitize_callback' => 'metz_sanitize_null' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_UpperWidgets', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_use3ColUpper', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_UpperWidgetsFront', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_Title', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_OptHdr', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_BotSdw', array( 'default' => '#dadada', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_CatsBackground', array( 'default' => '#9bbba1', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_CatsText', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_CatsBorder', array( 'default' => '#9bbba1', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_Content', array( 'default' => '#666', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_Link', array( 'default' => '#9b7d16', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_LinkHover', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_InputBackground', array( 'default' => '#f3f3f3', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_W_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_Title', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_OptHdr', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_Background', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_BotSdw', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_CatsBackground', array( 'default' => '#e5ecee', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_CatsText', array( 'default' => '#57818d', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_CatsBorder', array( 'default' => '#e5ecee', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_Content', array( 'default' => '#e5ecee', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_Link', array( 'default' => '#6fc4d4', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_LinkHover', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_InputBackground', array( 'default' => '#f3f3f3', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_WF_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	/* Slider */
	$wp_customize->add_setting( 'brnhmbx_sliderShortcode', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_SliderHomeView', array( 'default' => 'home-all', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SliderArchive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SliderPost', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_SliderPosition', array( 'default' => 'cover', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_Header', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_Caption', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_BBG', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_BBO', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_BT', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_Box', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_rng_Sli_Box', array( 'default' => 50, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_bpts', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_bptsNumber', array( 'default' => 5, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_bptsExclude', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_bptsDate', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderWidth', array( 'default' => 1080, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderHeight', array( 'default' => 500, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderCategory', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
	/* */
	$wp_customize->add_setting( 'brnhmbx_color_MenuLevel', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_RMBo', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_RMB', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_RMT', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_PageNumbers', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	/* Social Accounts */
	$wp_customize->add_setting( 'brnhmbx_social_Facebook', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Twitter', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Instagram', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Pinterest', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Google', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Tumblr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Flickr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Digg', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_LinkedIn', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Vimeo', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_YouTube', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Behance', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Dribble', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_DeviantArt', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Github', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Bloglovin', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Lastfm', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_SoundCloud', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_VK', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	/* */
	/* Translation */
	$wp_customize->add_setting( 'metz_ignorePot', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Lang', array( 'default' => ( get_bloginfo( 'language' ) ), 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_404', array( 'default' => 'PAGE NOT FOUND', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Nothing', array( 'default' => 'NOTHING FOUND', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_SearchResults', array( 'default' => 'Search Results', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Page', array( 'default' => 'PAGE', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Tag', array( 'default' => 'Tag', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Category', array( 'default' => 'Category', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Author', array( 'default' => 'Author', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Archives', array( 'default' => 'Archives', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_OlderPosts', array( 'default' => 'OLDER POSTS', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_NewerPosts', array( 'default' => 'NEWER POSTS', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_NextPost', array( 'default' => 'NEXT', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_PrevPost', array( 'default' => 'PREVIOUS', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_By', array( 'default' => 'by', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BackToTop', array( 'default' => 'BACK TO TOP', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_TypeKeyword', array( 'default' => 'Type keyword to search', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_ReadMore', array( 'default' => 'READ MORE', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Share', array( 'default' => 'SHARE', 'sanitize_callback' => 'sanitize_text_field' ) );
	// Post Comments
	$wp_customize->add_setting( 'brnhmbx_tra_Comment', array( 'default' => 'COMMENT', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Comments', array( 'default' => 'COMMENTS', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Name', array( 'default' => 'NAME', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Email', array( 'default' => 'E-MAIL', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Website', array( 'default' => 'WEBSITE', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_MustBeLogged', array( 'default' => 'YOU MUST BE LOGGED IN TO POST A COMMENT', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LoginToReply', array( 'default' => 'LOG IN TO REPLY', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Logged', array( 'default' => 'LOGGED IN', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LogOut', array( 'default' => 'LOG OUT', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LeaveReply', array( 'default' => 'Leave a Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_CancelReply', array( 'default' => 'CANCEL REPLY', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_PostComment', array( 'default' => 'POST COMMENT', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_At', array( 'default' => 'at', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Reply', array( 'default' => 'REPLY', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Edit', array( 'default' => 'EDIT', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Awaiting', array( 'default' => 'Comment awaiting approval', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_metz_tra_About', array( 'default' => 'about', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_metz_tra_AllByAuthor', array( 'default' => 'View All Posts by Author', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_metz_tra_AuthorWebsite', array( 'default' => 'Visit Author Website', 'sanitize_callback' => 'sanitize_text_field' ) );
	/* */
	$wp_customize->add_setting( 'brnhmbx_text_Footer', array( 'default' => '2019 METZ. ALL RIGHTS RESERVED.', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FooterWidth', array( 'default' => '1080', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_text_CSS', array( 'default' => '', 'sanitize_callback' => 'metz_sanitize_let_html' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Layout', array( 'default' => '2col_sidebar', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_metz_opt_HomePosts', array( 'default' => 'all', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_metz_text_HomePosts', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Layout_Archive', array( 'default' => '2col_sidebar', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_PageWidth', array( 'default' => '1080', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_styleA_count', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_styleB_count', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_explanation_1', array( 'default' => '0', 'sanitize_callback' => 'metz_sanitize_null' ) );
	$wp_customize->add_setting( 'brnhmbx_minHeight_styleA', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_minHeight_styleDefault', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	/* Post Comments */
	$wp_customize->add_setting( 'brnhmbx_color_PC_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_Header', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_Liner', array( 'default' => '#e3e3e3', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_Content', array( 'default' => '#666', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_DPL', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_Link', array( 'default' => '#9b7d16', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_InputBackground', array( 'default' => '#f3f3f3', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_BotSdw', array( 'default' => '#dadada', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_RMBo', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_RMB', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_PC_RMT', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	/* */
	/* Related Posts */
	$wp_customize->add_setting( 'brnhmbx_opt_RPStyle', array( 'default' => 'b', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RP_Box', array( 'default' => '#ebe4ca', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RP_Text', array( 'default' => '#756c4c', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_rng_RP_Box', array( 'default' => 100, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	/* Post Formats */
	$wp_customize->add_setting( 'brnhmbx_sh_FeaImg_Single_Standard', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Standard', array( 'default' => 'fea', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_HomeImg_Standard', array( 'default' => 'home', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_homeImageHeight', array( 'default' => 310, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Gallery', array( 'default' => 'gal', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_GalleryPos_Gallery', array( 'default' => 'content', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Video', array( 'default' => 'gal', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Standard', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Standard_Archive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Gallery', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Gallery_Archive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Video', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Video_Archive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Border', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_borderWidth_Standard', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Header', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_RMBo', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_RMB', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_RMT', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_BotSdw', array( 'default' => '#dadada', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Content', array( 'default' => '#666', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_DCB', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Social', array( 'default' => '#d5b977', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Link', array( 'default' => '#9b7d16', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_InputBackground', array( 'default' => '#f3f3f3', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_InputText', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_PostNavBackground', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_PostNavLink', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Teaser', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	/* */
	/* Show/Hide */
	$wp_customize->add_setting( 'brnhmbx_sh_btnToTop', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialAccounts', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPost_Standard', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPost_Gallery', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPost_Video', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarInnerPage', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarShop', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarProduct', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_RelatedPosts', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_metz_opt_RPBase', array( 'default' => 'tag', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_PostComments', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_PageComments', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Date', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Date_Home', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Hits', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Hits_Home', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Author', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_metz_sh_AuthorBox', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Excerpt', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_btnReadMore', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialBar', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialBar_Page', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialBar_Facebook', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialBar_Twitter', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialBar_Google', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_btnComments', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_btnComments_Home', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_TagBar', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_TagBar_Home', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_CategoryBar', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_CategoryBar_Home', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Teaser', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_BotSdw', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_MenuLink', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_MenuLink_Hover', array( 'default' => '#6fc4d4', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_HeaderLink', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_HeaderLink_Hover', array( 'default' => '#6fc4d4', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Menu_Background', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Background', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Content', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Link', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Link_Hover', array( 'default' => '#6fc4d4', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_BTT_BG', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_BTT_BO', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_BTT_T', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_FooterSocial', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_FooterMenu', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_use3ColFooter', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	/* */
	$wp_customize->add_setting( 'brnhmbx_mapPage', array( 'sanitize_callback' => 'metz_returnMapPageID' ) );
	$wp_customize->add_setting( 'brnhmbx_coorN', array( 'default' => '49.0138', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_coorE', array( 'default' => '8.38624', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_rng_MapZoom', array( 'default' => 15, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_mapHeight', array( 'default' => 500, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Map', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_enableMapKey', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_mapAPI', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_bxControls', array( 'default' => 'arrow', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_bxAuto', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_bxControls_Main', array( 'default' => 'arrow', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_bxAuto_Main', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderHideMobile', array( 'default' => 'always', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	/* Since v.1.8 */
	$wp_customize->add_setting( 'brnhmbx_sliderPause', array( 'default' => 4000, 'sanitize_callback' => 'metz_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderInfinite', array( 'default' => 1, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderRandom', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderMode', array( 'default' => 'horizontal', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	/* */
	/* Since v.1.3 */
	$wp_customize->add_setting( 'brnhmbx_text_Banner_1', array( 'default' => '', 'sanitize_callback' => 'metz_sanitize_let_html' ) );
	$wp_customize->add_setting( 'brnhmbx_text_Banner_2', array( 'default' => '', 'sanitize_callback' => 'metz_sanitize_let_html' ) );
	$wp_customize->add_setting( 'brnhmbx_text_Banner_3', array( 'default' => '', 'sanitize_callback' => 'metz_sanitize_let_html' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_BannerPos_1', array( 'default' => 'above-full-slider', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_BannerPos_2', array( 'default' => 'below-among-slider', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_BannerPos_3', array( 'default' => 'below-blog-posts', 'sanitize_callback' => 'metz_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Banner_1_Archive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Banner_1_Post', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Banner_2_Archive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Banner_2_Post', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Banner_3_Archive', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Banner_3_Post', array( 'default' => 0, 'sanitize_callback' => 'metz_sanitize_checkbox' ) );
	/* */

	// Controls
	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Favicon', array(
				'label' => esc_html__( '1.1. Favicon', 'metz' ),
				'section' => 'brnhmbx_sectionGeneral',
				'settings' => 'brnhmbx_upload_Favicon'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_imageWidth', array(
        'label' => esc_html__( '1.2. Featured Image Width', 'metz' ),
		'description' => wp_kses( __( 'Default value is "1080".<br>Write "0" to not to resize the images.<br>Works for only new added ones.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionGeneral',
        'settings' => 'brnhmbx_imageWidth',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_imageHeight', array(
        'label' => esc_html__( '1.3. Featured Image Height', 'metz' ),
		'description' => wp_kses( __( 'Default value is "0".<br>Write "0" to not to crop the images.<br>Works for only new added ones.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionGeneral',
        'settings' => 'brnhmbx_imageHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_HomeImg_Standard', array(
        'label' => esc_html__( '1.4. Home Thumbnail Options', 'metz' ),
		'description' => esc_html__( 'Does not affect post pages.', 'metz' ),
        'section' => 'brnhmbx_sectionGeneral',
        'settings' => 'brnhmbx_opt_HomeImg_Standard',
		'type' => 'radio',
		'choices' => array(
			'home' => 'Use Home Thumbnail',
			'fea' => 'Use Featured Image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_homeImageHeight', array(
        'label' => esc_html__( '1.5. Home Thumbnail Height', 'metz' ),
		'description' => wp_kses( __( 'Default value is "310".<br>Write "0" to not to crop the images.<br>Only used if "Use Home Thumbnail" is selected.<br>Works for only new added ones.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionGeneral',
        'settings' => 'brnhmbx_homeImageHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( new metz_font_selector( $wp_customize, 'metz2017_font_primary', array(
			'label' => esc_html__( '1.6. Primary Font', 'metz' ),
			'description' => esc_html__( 'Default: Playfair Display', 'metz' ),
			'section' => 'brnhmbx_sectionGeneral',
			'settings' => 'metz2017_font_primary'
		) ) );
	$wp_customize->add_control( new metz_font_selector( $wp_customize, 'metz2017_font_secondary', array(
			'label' => esc_html__( '1.7. Content Font', 'metz' ),
			'description' => esc_html__( 'Default: Arial', 'metz' ),
			'section' => 'brnhmbx_sectionGeneral',
			'settings' => 'metz2017_font_secondary',
	) ) );

	$wp_customize->add_control( 'brnhmbx_Uppercase', array(
        'label' => esc_html__( 'UPPERCASE Dates, Categories etc.', 'metz' ),
        'section' => 'brnhmbx_sectionGeneral',
        'settings' => 'brnhmbx_Uppercase',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_productPerPage', array(
        'label' => esc_html__( 'Number of Products per Page', 'metz' ),
		'description' => esc_html__( 'This setting is for WooCommerce only. Default value is "6".', 'metz' ),
        'section' => 'brnhmbx_sectionGeneral',
        'settings' => 'brnhmbx_productPerPage',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px;',
		),
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Background', array(
        'label' => esc_html__( '2.1. Background Color', 'metz' ), 'section' => 'brnhmbx_sectionBackground', 'settings' => 'brnhmbx_color_Background'
	) ) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Background', array(
				'label' => esc_html__( '2.2. Background Image', 'metz' ),
				'section' => 'brnhmbx_sectionBackground',
				'settings' => 'brnhmbx_upload_Background'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_centerBackground', array(
        'label' => esc_html__( 'Centered Background Image', 'metz' ),
        'section' => 'brnhmbx_sectionBackground',
        'settings' => 'brnhmbx_centerBackground',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_repeatBackground', array(
        'label' => esc_html__( '2.3. Background Repeat Options', 'metz' ),
		'description' => esc_html__( 'Only used if "Centered" is unchecked.', 'metz' ),
        'section' => 'brnhmbx_sectionBackground',
        'settings' => 'brnhmbx_repeatBackground',
		'type' => 'radio',
		'choices' => array(
			'no-repeat' => 'No Repeat',
			'repeat-x' => 'Repeat Only Horizontally',
			'repeat-y' => 'Repeat Only Vertically',
		)
    ) );

	/* Widget Common Colors */
	$wp_customize->add_control( 'brnhmbx_explanation_2', array(
        'label' => esc_html__( 'Header Widgets', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_explanation_2',
		'input_attrs' => array(
			'style' => 'display: none;',
		),
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_HeaderWidgets', array(
        'label' => esc_html__( 'Show Header Widgets', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_HeaderWidgets',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_headerWidgetsCol', array(
        'label' => esc_html__( '3 Header Widget Columns', 'metz' ),
		'description' => esc_html__( 'Uncheck for 2 columns.', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_headerWidgetsCol',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_HeaderWidgetsFront', array(
        'label' => esc_html__( 'First Page Header Widgets', 'metz' ),
		'description' => esc_html__( 'Shows header widgets only on the first page of pagination.', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_HeaderWidgetsFront',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_HeaderWidgetsPage', array(
        'label' => esc_html__( 'Show Header Widgets on Pages', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_HeaderWidgetsPage',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_HeaderWidgetsPost', array(
        'label' => esc_html__( 'Show Header Widgets on Posts', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_HeaderWidgetsPost',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_HeaderWidgetsArchive', array(
        'label' => esc_html__( 'Show Header Widgets on Archives', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_HeaderWidgetsArchive',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_explanation_3', array(
        'label' => esc_html__( 'Upper Widgets', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_explanation_3',
		'input_attrs' => array(
			'style' => 'display: none;',
		),
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_UpperWidgets', array(
        'label' => esc_html__( 'Show Upper Widgets', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_UpperWidgets',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_use3ColUpper', array(
        'label' => esc_html__( '3 Upper Widget Columns', 'metz' ),
		'description' => wp_kses( __( '3 columns option is only used with layouts have no sidebar.<br>Uncheck for 2 columns.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_use3ColUpper',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_UpperWidgetsFront', array(
        'label' => esc_html__( 'First Page Upper Widgets', 'metz' ),
		'description' => esc_html__( 'Shows upper widgets only on the first page of pagination.', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_UpperWidgetsFront',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_explanation_4', array(
        'label' => esc_html__( 'Home Widgets', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_explanation_4',
		'input_attrs' => array(
			'style' => 'display: none;',
		),
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_HomeWidgets', array(
        'label' => esc_html__( 'Show Home Widgets', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_HomeWidgets',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_use3ColHome', array(
        'label' => esc_html__( '3 Home Widget Columns', 'metz' ),
		'description' => wp_kses( __( '3 columns option is only used with layouts have no sidebar.<br>Uncheck for 2 columns.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_use3ColHome',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_HomeWidgetsFront', array(
        'label' => esc_html__( 'First Page Home Widgets', 'metz' ),
		'description' => esc_html__( 'Shows home widgets only on the first page of pagination.', 'metz' ),
        'section' => 'brnhmbx_sectionHomeWidgets',
        'settings' => 'brnhmbx_sh_HomeWidgetsFront',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_Background', array(
        'label' => esc_html__( 'Background Color', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_Background'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_BotSdw', array(
        'label' => esc_html__( 'Bottom Line Color', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_BotSdw'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_Title', array(
        'label' => esc_html__( 'Title Color', 'metz' ), 'description' => esc_html__( 'Also used for comments & hits icons.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_Title'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_OptHdr', array(
        'label' => esc_html__( 'Headline Color', 'metz' ), 'description' => esc_html__( 'Also used for dates.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_OptHdr'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_CatsBackground', array(
        'label' => esc_html__( 'Button Background Color', 'metz' ), 'description' => esc_html__( 'Used for "Tags/Categories Widget" only.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_CatsBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_CatsText', array(
        'label' => esc_html__( 'Button Text Color', 'metz' ), 'description' => esc_html__( 'Used for "Tags/Categories Widget" only.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_CatsText'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_CatsBorder', array(
        'label' => esc_html__( 'Button Border Color', 'metz' ), 'description' => esc_html__( 'Used for "Tags/Categories Widget" only.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_CatsBorder'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_Content', array(
        'label' => esc_html__( 'Content Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_Link', array(
        'label' => esc_html__( 'Link Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_Link'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_LinkHover', array(
        'label' => esc_html__( 'Link Hover Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_LinkHover'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_W_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionHomeWidgets', 'settings' => 'brnhmbx_color_W_InputText'
	) ) );

	/* */

	/* Slider Colors & Settings */
	$wp_customize->add_control( 'brnhmbx_bpts', array(
        'label' => esc_html__( 'Show Blog Posts in Slider', 'metz' ),
		'description' => esc_html__( 'Disables the shortcode if checked.', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_bpts',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sliderCategory', array(
		'description' => esc_html__( 'Write a category slug to show the category posts in slider. Leave blank to show all posts. Only used if "Show Blog Posts in Slider" is checked.', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderCategory',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );
	$wp_customize->add_control( 'brnhmbx_bptsNumber', array(
		'description' => wp_kses( __( 'Number of the posts to show in slider:<br>Only used if "Show Blog Posts in Slider" is checked.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_bptsNumber',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );
	$wp_customize->add_control( 'brnhmbx_bptsExclude', array(
        'label' => esc_html__( 'Exclude the Slider Posts From Feed', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_bptsExclude',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_bptsDate', array(
        'label' => esc_html__( 'Show Post Dates', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_bptsDate',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sliderShortcode', array(
        'label' => esc_html__( '4.1. Shortcode', 'metz' ),
				'description' => wp_kses( __( 'Example usages:<br>Old Slider:<br>[metzslider location="your_location"]<br>New Slider:<br>[new_metzslider group="your_group"]', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderShortcode',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );
	$wp_customize->add_control( 'brnhmbx_opt_SliderHomeView', array(
        'label' => esc_html__( '4.2. Home View Options', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_opt_SliderHomeView',
		'type' => 'radio',
		'choices' => array(
			'home-all' => 'During Pagination',
			'home-front' => 'Only on the First Page of Pagination',
			'home-hide' => 'Hide at Home'
		)
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_SliderArchive', array(
        'label' => esc_html__( 'Show Slider on Archive Pages', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sh_SliderArchive',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_SliderPost', array(
        'label' => esc_html__( 'Show Slider on Post Pages', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sh_SliderPost',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_opt_SliderPosition', array(
        'label' => esc_html__( '4.3. Position & Style', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_opt_SliderPosition',
		'type' => 'radio',
		'choices' => array(
			'full' => 'Fullwidth',
			'cover' => 'Cover',
			'among' => 'Among the Posts'
		)
    ) );
	$wp_customize->add_control( 'brnhmbx_opt_bxControls_Main', array(
		'label' => esc_html__( '4.4. Control Settings', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_opt_bxControls_Main',
		'type' => 'radio',
		'choices' => array(
			'arrow' => 'Show Prev/Next Arrows',
			'bullet' => 'Show Pager Bullets',
			'both' => 'Show Both',
			'none' => 'None'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_bxAuto_Main', array(
		'label' => esc_html__( 'Autoplay Slides', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_bxAuto_Main',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderPause', array(
        'label' => esc_html__( 'Autoplay Duration', 'metz' ),
		'description' => wp_kses( __( 'Default value is "4000".<br>Only used if "Autoplay Slides" is checked.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderPause',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderWidth', array(
        'label' => esc_html__( '4.5. Slide Image Width', 'metz' ),
		'description' => wp_kses( __( 'Default value is "1080".<br>Since the slider is responsive, display results may seem different. If you want to use "Fullwidth" option for instance, to set it 2560 and upload big images make sense.<br>Works for only new added images.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderWidth',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderHeight', array(
        'label' => esc_html__( '4.6. Slide Image Height', 'metz' ),
		'description' => wp_kses( __( 'Default value is "500".<br>This value is fixed, not responsive.<br>Works for only new added images.', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderHideMobile', array(
		'label' => esc_html__( '4.7. Mobile Settings', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderHideMobile',
		'type' => 'radio',
		'choices' => array(
			'always' => 'Always Show',
			'320' => 'Hide at 320px',
			'480' => 'Hide at 480px',
			'640' => 'Hide at 640px'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderMode', array(
		'label' => esc_html__( '4.8. Transition Effect', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderMode',
		'type' => 'radio',
		'choices' => array(
			'horizontal' => 'Horizontal',
			'fade' => 'Fade'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderInfinite', array(
		'label' => esc_html__( 'Infinite Loop', 'metz' ),
		'description' => esc_html__( 'If checked, clicking "Next" while on the last slide will transition to the first slide and vice-versa.', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderInfinite',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderRandom', array(
		'label' => esc_html__( 'Start with a Random Slide', 'metz' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderRandom',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_Header', array(
        'label' => esc_html__( 'Header Color', 'metz' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_Caption', array(
        'label' => esc_html__( 'Caption Color', 'metz' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_Caption'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_BBG', array(
        'label' => esc_html__( 'Button Background Color', 'metz' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_BBG'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_BBO', array(
        'label' => esc_html__( 'Button Border Color', 'metz' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_BBO'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_BT', array(
        'label' => esc_html__( 'Button Text Color', 'metz' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_BT'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_Box', array(
        'label' => esc_html__( 'Box Color', 'metz' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_Box'
	) ) );
	$wp_customize->add_control( 'brnhmbx_rng_Sli_Box', array(
		'type'        => 'range',
		'section'     => 'brnhmbx_sectionSlider',
		'label'       => 'Slider Box Opacity',
		'input_attrs' => array(
			'min'   => 0,
			'max'   => 100,
			'step'  => 10
		)
	) );
	/* */
	$wp_customize->add_control( 'brnhmbx_text_Logo', array(
        'label' => esc_html__( '3.1. Logo Text', 'metz' ),
		'description' => esc_html__( 'Leave blank if you want to use the "Site Title". If a logo image is uploaded, this will never be shown.', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_text_Logo',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Logo', array(
        'label' => esc_html__( '3.2 Logo Text Color', 'metz' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_Logo'
	) ) );

	$wp_customize->add_control( 'brnhmbx_useFAIcon', array(
        'label' => esc_html__( '3.3. Font Awesome Icon', 'metz' ),
		'description' => wp_kses( __( "Choose from <a href='http://fortawesome.github.io/Font-Awesome/cheatsheet/' target='_blank'>'Font Awesome Cheatsheet'</a>.<br>Leave blank if you don't want to use.<br>Only used with text logo.", 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_useFAIcon',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Logo', array(
				'label' => esc_html__( '3.4. Logo Image', 'metz' ),
				'section' => 'brnhmbx_sectionHeader',
				'settings' => 'brnhmbx_upload_Logo'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_LogoRetina', array(
				'label' => esc_html__( '3.5. Logo Image (Retina)', 'metz' ),
				'description' => esc_html__( 'Must be 2X bigger from the original.', 'metz' ),
				'section' => 'brnhmbx_sectionHeader',
				'settings' => 'brnhmbx_upload_LogoRetina'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_StickyLogo', array(
				'label' => esc_html__( '3.6. Sticky Logo Image', 'metz' ),
				'section' => 'brnhmbx_sectionHeader',
				'settings' => 'brnhmbx_upload_StickyLogo'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_opt_MenuWidth', array(
		'label' => esc_html__( '3.7. Header Width', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_opt_MenuWidth',
		'type' => 'radio',
		'choices' => array(
			'1080' => '1080 px',
			'full' => 'Fullwidth'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_MenuPos', array(
        'label' => esc_html__( '3.8. Logo Position', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_opt_MenuPos',
		'type' => 'radio',
		'choices' => array(
			'logo-very-top' => 'Top (Outside of the Box)',
			'logo-top' => 'Top',
			'logo-left' => 'Left',
			'logo-bottom' => 'Bottom (Outside of the Box)'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_logoPaddingTop', array(
        'label' => esc_html__( '3.9. Logo Top Padding', 'metz' ),
		'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_logoPaddingTop',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_logoPaddingBottom', array(
        'label' => esc_html__( '3.10. Logo Bottom Padding', 'metz' ),
		'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_logoPaddingBottom',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_StickyLogo', array(
        'label' => esc_html__( 'Show Sticky Logo', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_sh_StickyLogo',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_HeaderSocial', array(
        'label' => esc_html__( 'Show Social Account Icons', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_sh_HeaderSocial',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_HeaderMenu', array(
        'label' => esc_html__( 'Show Header Menu', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_sh_HeaderMenu',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_stickyHeader', array(
        'label' => esc_html__( 'Sticky Header', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_stickyHeader',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_triggerSticky', array(
		'description' => esc_html__( 'Trigger sticky header when scroll position is higher than:', 'metz' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_triggerSticky',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

		$wp_customize->add_control( 'metz_slicknav_apl', array(
			'label' => esc_html__( 'Clickable Parent Menu Items in Mobile Menu', 'metz' ),
			'section' => 'brnhmbx_sectionHeader',
			'settings' => 'metz_slicknav_apl',
			'type' => 'checkbox'
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Menu_Background', array(
        'label' => esc_html__( 'Menu Background Color', 'metz' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_Menu_Background'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_MenuLevel', array(
        'label' => esc_html__( 'Menu Level Background Color', 'metz' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_MenuLevel'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_MenuLink', array(
        'label' => esc_html__( 'Menu Link Color', 'metz' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_MenuLink'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_MenuLink_Hover', array(
        'label' => esc_html__( 'Menu Link Hover Color', 'metz' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_MenuLink_Hover'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_HeaderLink', array(
        'label' => esc_html__( 'Header Menu Link Color', 'metz' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_HeaderLink'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_HeaderLink_Hover', array(
        'label' => esc_html__( 'Header Menu Link Hover Color', 'metz' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_HeaderLink_Hover'
	) ) );

	/* Social Accounts */
	$wp_customize->add_control( 'brnhmbx_sh_SocialAccounts', array(
        'label' => esc_html__( 'Show Social Account Icons', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_sh_SocialAccounts',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Facebook', array(
        'label' => esc_html__( 'Facebook', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Facebook',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Twitter', array(
        'label' => esc_html__( 'Twitter', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Twitter',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Instagram', array(
        'label' => esc_html__( 'Instagram', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Instagram',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Pinterest', array(
        'label' => esc_html__( 'Pinterest', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Pinterest',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Google', array(
        'label' => esc_html__( 'Google+', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Google',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Tumblr', array(
        'label' => esc_html__( 'Tumblr', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Tumblr',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Flickr', array(
        'label' => esc_html__( 'Flickr', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Flickr',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Digg', array(
        'label' => esc_html__( 'Digg', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Digg',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_LinkedIn', array(
        'label' => esc_html__( 'LinkedIn', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_LinkedIn',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Vimeo', array(
        'label' => esc_html__( 'Vimeo', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Vimeo',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_YouTube', array(
        'label' => esc_html__( 'YouTube', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_YouTube',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Behance', array(
        'label' => esc_html__( 'Behance', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Behance',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Dribble', array(
        'label' => esc_html__( 'Dribbble', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Dribble',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_DeviantArt', array(
        'label' => esc_html__( 'DeviantArt', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_DeviantArt',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Github', array(
        'label' => esc_html__( 'Github', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Github',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Bloglovin', array(
        'label' => esc_html__( "Bloglovin'", 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Bloglovin',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Lastfm', array(
        'label' => esc_html__( 'Last.fm', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Lastfm',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_SoundCloud', array(
        'label' => esc_html__( 'SoundCloud', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_SoundCloud',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_VK', array(
        'label' => esc_html__( 'VK', 'metz' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_VK',
		'type' => 'text',
    ) );
	/* */

	/* Translation */
	$wp_customize->add_control( 'metz_ignorePot', array(
        'label' => esc_html__( 'Ignore .pot file and use the translations below.', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'metz_ignorePot',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Lang', array(
        'label' => esc_html__( '18.1. Site Language', 'metz' ),
		'description' => esc_html__( 'Original: "', 'metz' ) . esc_html( get_bloginfo( 'language' ) ) . '"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Lang',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_404', array(
        'label' => esc_html__( '18.2. Wording', 'metz' ),
		'description' => esc_html__( 'Original: "PAGE NOT FOUND"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_404',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Nothing', array(
		'description' => esc_html__( 'Original: "NOTHING FOUND"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Nothing',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_SearchResults', array(
		'description' => esc_html__( 'Original: "Search Results"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_SearchResults',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Page', array(
		'description' => esc_html__( 'Original: "PAGE"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Page',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Tag', array(
		'description' => esc_html__( 'Original: "Tag"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Tag',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Category', array(
		'description' => esc_html__( 'Original: "Category"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Category',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Author', array(
		'description' => esc_html__( 'Original: "Author"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Author',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Archives', array(
		'description' => esc_html__( 'Original: "Archives"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Archives',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_OlderPosts', array(
		'description' => esc_html__( 'Original: "OLDER POSTS"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_OlderPosts',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_NewerPosts', array(
		'description' => esc_html__( 'Original: "NEWER POSTS"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_NewerPosts',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_NextPost', array(
		'description' => esc_html__( 'Original: "NEXT"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_NextPost',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_PrevPost', array(
		'description' => esc_html__( 'Original: "PREVIOUS"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_PrevPost',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_By', array(
		'description' => esc_html__( 'Original: "by"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_By',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BackToTop', array(
		'description' => esc_html__( 'Original: "BACK TO TOP"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BackToTop',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_TypeKeyword', array(
		'description' => esc_html__( 'Original: "Type keyword to search"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_TypeKeyword',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_ReadMore', array(
		'description' => esc_html__( 'Original: "READ MORE"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_ReadMore',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Share', array(
		'description' => esc_html__( 'Original: "SHARE"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Share',
		'type' => 'text',
    ) );

	// Post Comments
	$wp_customize->add_control( 'brnhmbx_tra_Comment', array(
		'description' => esc_html__( 'Original: "COMMENT"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Comment',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Comments', array(
		'description' => esc_html__( 'Original: "COMMENTS"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Comments',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Name', array(
		'description' => esc_html__( 'Original: "NAME"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Name',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Email', array(
		'description' => esc_html__( 'Original: "E-MAIL"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Email',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Website', array(
		'description' => esc_html__( 'Original: "WEBSITE"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Website',
		'type' => 'text',
    ) );

		$wp_customize->add_control( 'brnhmbx_tra_MustBeLogged', array(
			'description' => esc_html__( 'Original: "YOU MUST BE LOGGED IN TO POST A COMMENT"', 'metz' ),
	        'section' => 'brnhmbx_sectionTranslation',
	        'settings' => 'brnhmbx_tra_MustBeLogged',
			'type' => 'text',
	    ) );

		$wp_customize->add_control( 'brnhmbx_tra_LoginToReply', array(
				'description' => esc_html__( 'Original: "LOG IN TO REPLY"', 'metz' ),
		        'section' => 'brnhmbx_sectionTranslation',
		        'settings' => 'brnhmbx_tra_LoginToReply',
				'type' => 'text',
		    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Logged', array(
		'description' => esc_html__( 'Original: "LOGGED IN"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Logged',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_LogOut', array(
		'description' => esc_html__( 'Original: "LOG OUT"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_LogOut',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_LeaveReply', array(
		'description' => esc_html__( 'Original: "Leave a Reply"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_LeaveReply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_CancelReply', array(
		'description' => esc_html__( 'Original: "CANCEL REPLY"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_CancelReply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_PostComment', array(
		'description' => esc_html__( 'Original: "POST COMMENT"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_PostComment',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_At', array(
		'description' => esc_html__( 'Original: "at"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_At',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Reply', array(
		'description' => esc_html__( 'Original: "REPLY"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Reply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Edit', array(
		'description' => esc_html__( 'Original: "EDIT"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Edit',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Awaiting', array(
		'description' => esc_html__( 'Original: "Comment awaiting approval"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Awaiting',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_metz_tra_About', array(
		'description' => esc_html__( 'Original: "about"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_metz_tra_About',
		'type' => 'text',
    ) );
	$wp_customize->add_control( 'brnhmbx_metz_tra_AllByAuthor', array(
		'description' => esc_html__( 'Original: "View All Posts by Author"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_metz_tra_AllByAuthor',
		'type' => 'text',
    ) );
	$wp_customize->add_control( 'brnhmbx_metz_tra_AuthorWebsite', array(
		'description' => esc_html__( 'Original: "Visit Author Website"', 'metz' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_metz_tra_AuthorWebsite',
		'type' => 'text',
    ) );
	/* */

	$wp_customize->add_control( 'brnhmbx_opt_FooterWidth', array(
		'label' => esc_html__( '13.1. Container Width', 'metz' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_opt_FooterWidth',
		'type' => 'radio',
		'choices' => array(
			'1080' => '1080 px',
			'full' => 'Fullwidth'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_text_Footer', array(
        'label' => esc_html__( '13.2. Copyright Text', 'metz' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_text_Footer',
		'type' => 'text',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Content', array(
        'label' => esc_html__( 'Copyright Text Color', 'metz' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Content'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Background', array(
        'label' => esc_html__( 'Background Color', 'metz' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Background'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Link', array(
        'label' => esc_html__( 'Menu Link Color', 'metz' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Link'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Link_Hover', array(
        'label' => esc_html__( 'Menu Link Hover Color', 'metz' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Link_Hover'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_BTT_BG', array(
        'label' => esc_html__( '"Back to Top" Background Color', 'metz' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_BTT_BG'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_BTT_BO', array(
        'label' => esc_html__( '"Back to Top" Border Color', 'metz' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_BTT_BO'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_BTT_T', array(
        'label' => esc_html__( '"Back to Top" Text Color', 'metz' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_BTT_T'
	) ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnToTop', array(
        'label' => esc_html__( 'Show "Back to Top" Button', 'metz' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_sh_btnToTop',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_FooterMenu', array(
        'label' => esc_html__( 'Show Footer Menu', 'metz' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_sh_FooterMenu',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_FooterSocial', array(
        'label' => esc_html__( 'Show Social Account Icons', 'metz' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_sh_FooterSocial',
		'type' => 'checkbox'
    ) );

	// Widgets
	$wp_customize->add_control( 'brnhmbx_use3ColFooter', array(
        'label' => esc_html__( '3 Widget Columns', 'metz' ),
		'description' => esc_html__( 'Uncheck for 2 columns.', 'metz' ),
        'section' => 'brnhmbx_sectionFooterWidgets',
        'settings' => 'brnhmbx_use3ColFooter',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_Background', array(
        'label' => esc_html__( 'Background Color', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_Background'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_BotSdw', array(
        'label' => esc_html__( 'Bottom Line Color', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_BotSdw'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_Title', array(
        'label' => esc_html__( 'Title Color', 'metz' ), 'description' => esc_html__( 'Also used for comments & hits icons.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_Title'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_OptHdr', array(
        'label' => esc_html__( 'Headline Color', 'metz' ), 'description' => esc_html__( 'Also used for dates.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_OptHdr'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_CatsBackground', array(
        'label' => esc_html__( 'Button Background Color', 'metz' ), 'description' => esc_html__( 'Used for "Tags/Categories Widget" only.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_CatsBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_CatsText', array(
        'label' => esc_html__( 'Button Text Color', 'metz' ), 'description' => esc_html__( 'Used for "Tags/Categories Widget" only.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_CatsText'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_CatsBorder', array(
        'label' => esc_html__( 'Button Border Color', 'metz' ), 'description' => esc_html__( 'Used for "Tags/Categories Widget" only.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_CatsBorder'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_Content', array(
        'label' => esc_html__( 'Content Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_Link', array(
        'label' => esc_html__( 'Link Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_Link'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_LinkHover', array(
        'label' => esc_html__( 'Link Hover Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_LinkHover'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_WF_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'metz' ), 'description' => esc_html__( 'Used for WP default widgets.', 'metz' ), 'section' => 'brnhmbx_sectionFooterWidgets', 'settings' => 'brnhmbx_color_WF_InputText'
	) ) );
	/* */

	$wp_customize->add_control( 'brnhmbx_opt_PageWidth', array(
		'label' => esc_html__( '6.1. Page Width', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_opt_PageWidth',
		'type' => 'radio',
		'choices' => array(
			'1080' => '1080 px',
			'full' => 'Fullwidth'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_Layout', array(
		'label' => esc_html__( '6.2. Home Display Options', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_opt_Layout',
		'type' => 'radio',
		'choices' => array(
			'1col' => '1 Column',
			'1col_sidebar' => '1 Column + Sidebar',
			'2col' => '2 Columns',
			'2col_sidebar' => '2 Columns + Sidebar',
			'1_2col_sidebar' => '(1 + 2) Columns + Sidebar',
			'3col' => '3 Columns',
			'2_3col' => '(2 + 3) Columns'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_metz_text_HomePosts', array(
		'label' => esc_html__( 'Show/Hide Specific Categories on Homepage', 'metz' ),
        'description' => wp_kses( __( 'Write category IDs you want to show or hide. Use comma (,) between them.<br>Example: 2,5,8', 'metz' ), $metz_allowed_html ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_metz_text_HomePosts',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_metz_opt_HomePosts', array(
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_metz_opt_HomePosts',
		'type' => 'radio',
		'choices' => array(
			'all' => 'Show All Categories',
			'hidecats' => 'Hide Chosen Categories',
			'showcats' => 'Show Chosen Categories'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_Layout_Archive', array(
		'label' => esc_html__( '6.3. Archive Display Options', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_opt_Layout_Archive',
		'type' => 'radio',
		'choices' => array(
			'1col' => '1 Column',
			'1col_sidebar' => '1 Column + Sidebar',
			'2col' => '2 Columns',
			'2col_sidebar' => '2 Columns + Sidebar',
			'1_2col_sidebar' => '(1 + 2) Columns + Sidebar',
			'3col' => '3 Columns',
			'2_3col' => '(2 + 3) Columns'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_styleA_count', array(
		'label' => esc_html__( '6.4. Listing Style Options', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
		'description' => esc_html__( 'Number of posts to show in "Style A":', 'metz' ),
        'settings' => 'brnhmbx_styleA_count',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_styleB_count', array(
        'section' => 'brnhmbx_sectionLayout',
		'description' => esc_html__( 'Number of posts to show in "Style B":', 'metz' ),
        'settings' => 'brnhmbx_styleB_count',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_explanation_1', array(
        'label' => esc_html__( '6.5. Listing Style Heights', 'metz' ),
		'description' => esc_html__( 'If you have problems about equalizing the heights of your posts (homepage views), you can set a static size to make their heights equal.', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_explanation_1',
		'input_attrs' => array(
			'style' => 'display: none;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_minHeight_styleDefault', array(
        'section' => 'brnhmbx_sectionLayout',
		'description' => esc_html__( 'Minimum height for default item:', 'metz' ),
        'settings' => 'brnhmbx_minHeight_styleDefault',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_minHeight_styleA', array(
        'section' => 'brnhmbx_sectionLayout',
		'description' => esc_html__( 'Minimum height for Style A item:', 'metz' ),
        'settings' => 'brnhmbx_minHeight_styleA',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPost_Standard', array(
		'label' => esc_html__( 'Show Sidebar on Standard Posts', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarPost_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPost_Gallery', array(
		'label' => esc_html__( 'Show Sidebar on Gallery Posts', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarPost_Gallery',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPost_Video', array(
		'label' => esc_html__( 'Show Sidebar on Video Posts', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarPost_Video',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarInnerPage', array(
		'label' => esc_html__( 'Show Sidebar on Pages', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarInnerPage',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarShop', array(
		'label' => esc_html__( 'Show Sidebar on Shop Pages', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarShop',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarProduct', array(
		'label' => esc_html__( 'Show Sidebar on Product Pages', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarProduct',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ExtraSidebar_Archive', array(
        'label' => esc_html__( 'Enable "Sidebar - Archive"', 'metz' ),
		'description' => esc_html__( 'Uncheck to use the default sidebar.', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_ExtraSidebar_Archive',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_ExtraSidebar_Page', array(
        'label' => esc_html__( 'Enable "Sidebar - Page"', 'metz' ),
		'description' => esc_html__( 'Uncheck to use the default sidebar.', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_ExtraSidebar_Page',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_ExtraSidebar_Post', array(
        'label' => esc_html__( 'Enable "Sidebar - Post"', 'metz' ),
		'description' => esc_html__( 'Uncheck to use the default sidebar.', 'metz' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_ExtraSidebar_Post',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_RelatedPosts', array(
		'label' => esc_html__( 'Show Related Posts', 'metz' ),
        'section' => 'brnhmbx_sectionRP',
        'settings' => 'brnhmbx_sh_RelatedPosts',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_metz_opt_RPBase', array(
		'label' => esc_html__( 'Related Term', 'metz' ),
        'section' => 'brnhmbx_sectionRP',
        'settings' => 'brnhmbx_metz_opt_RPBase',
		'type' => 'radio',
		'choices' => array(
			'tag' => 'Tag',
			'category' => 'Category'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_RPStyle', array(
		'label' => esc_html__( '11.1. Listing Style', 'metz' ),
        'section' => 'brnhmbx_sectionRP',
        'settings' => 'brnhmbx_opt_RPStyle',
		'type' => 'radio',
		'choices' => array(
			'a' => 'Style A',
			'b' => 'Style B'
		)
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RP_Box', array(
        'label' => esc_html__( 'Box Color', 'metz' ), 'section' => 'brnhmbx_sectionRP', 'settings' => 'brnhmbx_color_RP_Box'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RP_Text', array(
        'label' => esc_html__( 'Text Color', 'metz' ), 'section' => 'brnhmbx_sectionRP', 'settings' => 'brnhmbx_color_RP_Text'
	) ) );

	$wp_customize->add_control( 'brnhmbx_rng_RP_Box', array(
		'type'        => 'range',
		'section'     => 'brnhmbx_sectionRP',
		'label'       => 'Box Opacity',
		'input_attrs' => array(
			'min'   => 0,
			'max'   => 100,
			'step'  => 10
		)
	) );

	$wp_customize->add_control( 'brnhmbx_sh_PostComments', array(
		'label' => esc_html__( 'Show Post Comments', 'metz' ),
        'section' => 'brnhmbx_sectionPC',
        'settings' => 'brnhmbx_sh_PostComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_PageComments', array(
		'label' => esc_html__( 'Show Page Comments', 'metz' ),
        'section' => 'brnhmbx_sectionPC',
        'settings' => 'brnhmbx_sh_PageComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_FeaImg_Single_Standard', array(
		'label' => esc_html__( 'Show Featured Image on Post Pages', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_sh_FeaImg_Single_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Standard', array(
		'label' => esc_html__( 'Show full post at Home Page', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_ignoreExcerpt_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Standard_Archive', array(
		'label' => esc_html__( 'Show full post on Archive Pages', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_ignoreExcerpt_Standard_Archive',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Gallery', array(
		'label' => esc_html__( 'Show full post at Home Page', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_ignoreExcerpt_Gallery',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Gallery_Archive', array(
		'label' => esc_html__( 'Show full post on Archive Pages', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_ignoreExcerpt_Gallery_Archive',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Video', array(
		'label' => esc_html__( 'Show full post at Home Page', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatVideo',
        'settings' => 'brnhmbx_ignoreExcerpt_Video',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Video_Archive', array(
		'label' => esc_html__( 'Show full post on Archive Pages', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatVideo',
        'settings' => 'brnhmbx_ignoreExcerpt_Video_Archive',
		'type' => 'checkbox',
    ) );

	/* Show/Hide Elements */
	$wp_customize->add_control( 'brnhmbx_sh_Date', array(
		'label' => esc_html__( 'Show Date', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Date',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Date_Home', array(
		'label' => esc_html__( 'Show Date', 'metz' ),
		'description' => esc_html__( 'For indexed views like home, archives etc.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Date_Home',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnComments', array(
		'label' => esc_html__( 'Show Comments Icon', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_btnComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnComments_Home', array(
		'label' => esc_html__( 'Show Comments Icon', 'metz' ),
		'description' => esc_html__( 'For indexed views like home, archives etc.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_btnComments_Home',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Hits', array(
		'label' => esc_html__( 'Show Hit Counter', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Hits',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Hits_Home', array(
		'label' => esc_html__( 'Show Hit Counter', 'metz' ),
		'description' => esc_html__( 'For indexed views like home, archives etc.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Hits_Home',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Teaser', array(
		'label' => esc_html__( 'Show Excerpt', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Teaser',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Excerpt', array(
		'label' => esc_html__( 'Show Excerpt', 'metz' ),
		'description' => esc_html__( 'For indexed views like home, archives etc.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Excerpt',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_TagBar', array(
		'label' => esc_html__( 'Show Tags', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_TagBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_TagBar_Home', array(
		'label' => esc_html__( 'Show Tags', 'metz' ),
		'description' => esc_html__( 'For indexed views like home, archives etc.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_TagBar_Home',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_CategoryBar', array(
		'label' => esc_html__( 'Show Categories', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_CategoryBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_CategoryBar_Home', array(
		'label' => esc_html__( 'Show Categories', 'metz' ),
		'description' => esc_html__( 'For indexed views like home, archives etc.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_CategoryBar_Home',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnReadMore', array(
		'label' => esc_html__( 'Show Read More Button', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_btnReadMore',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Author', array(
		'label' => esc_html__( 'Show Author', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Author',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_metz_sh_AuthorBox', array(
		'label' => esc_html__( 'Show Author Box on Post Pages', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_metz_sh_AuthorBox',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SocialBar', array(
		'label' => esc_html__( 'Show Share Icons', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_SocialBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SocialBar_Page', array(
		'label' => esc_html__( 'Show Share Icons on Pages', 'metz' ),
		'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_SocialBar_Page',
		'type' => 'checkbox',
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_SocialBar_Facebook', array(
		'label' => esc_html__( 'Show Facebook Share Icon', 'metz' ),
		'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_SocialBar_Facebook',
		'type' => 'checkbox',
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_SocialBar_Twitter', array(
		'label' => esc_html__( 'Show Twitter Share Icon', 'metz' ),
		'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_SocialBar_Twitter',
		'type' => 'checkbox',
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_SocialBar_Google', array(
		'label' => esc_html__( 'Show Google Share Icon', 'metz' ),
		'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_SocialBar_Google',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_BotSdw', array(
        'label' => esc_html__( 'Show Bottom Line', 'metz' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_BotSdw',
		'type' => 'checkbox',
    ) );
	/* */

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Standard', array(
        'label' => esc_html__( '8.1. Featured Image Options', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_opt_FeaImg_Standard',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'no' => 'No image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Gallery', array(
        'label' => esc_html__( '9.1. Featured Image Options', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_opt_FeaImg_Gallery',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'gal' => 'Show gallery image(s)',
			'no' => 'No image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_GalleryPos_Gallery', array(
        'label' => esc_html__( '9.2. Gallery Position', 'metz' ),
		'description' => esc_html__( 'Choose the gallery position on post page.', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_opt_GalleryPos_Gallery',
		'type' => 'radio',
		'choices' => array(
			'content' => 'Only in Content',
			'iof' => 'Instead of Featured Image',
			'both' => 'Both'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_bxControls', array(
		'label' => esc_html__( '9.3. Gallery Slider Settings', 'metz' ),
		'description' => esc_html__( 'Video sliders will use these settings too.', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_opt_bxControls',
		'type' => 'radio',
		'choices' => array(
			'arrow' => 'Show Prev/Next Arrows',
			'bullet' => 'Show Pager Bullets',
			'both' => 'Show Both',
			'none' => 'None'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_bxAuto', array(
		'label' => esc_html__( 'Autoplay Slides', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_bxAuto',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Video', array(
        'label' => esc_html__( '10.1. Featured Image Options', 'metz' ),
        'section' => 'brnhmbx_sectionPostFormatVideo',
        'settings' => 'brnhmbx_opt_FeaImg_Video',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'gal' => 'Show video(s)',
			'no' => 'No image'
		)
    ) );

	/* Related Posts & Post Comments */
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_Background', array(
        'label' => esc_html__( 'Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_Background'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_BotSdw', array(
        'label' => esc_html__( 'Bottom Line Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_BotSdw'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_Header', array(
        'label' => esc_html__( 'Header Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_Liner', array(
        'label' => esc_html__( 'Separator Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_Liner'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_Content', array(
        'label' => esc_html__( 'Content Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_DPL', array(
        'label' => esc_html__( 'Secondary Content Color', 'metz' ), 'description' => esc_html__( 'Used for date etc.', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_DPL'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_Link', array(
        'label' => esc_html__( 'Link Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_Link'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_InputText'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_RMBo', array(
        'label' => esc_html__( 'Button Border Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_RMBo'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_RMB', array(
        'label' => esc_html__( 'Button Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_RMB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_PC_RMT', array(
        'label' => esc_html__( 'Button Text Color', 'metz' ), 'section' => 'brnhmbx_sectionPC', 'settings' => 'brnhmbx_color_PC_RMT'
	) ) );
	/* */

	/* Post Format Colors*/
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Background', array(
        'label' => esc_html__( 'Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_Background'
	) ) );
	$wp_customize->add_control( 'brnhmbx_borderWidth_Standard', array(
        'label' => esc_html__( 'Border Width', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_borderWidth_Standard', 'type' => 'number', 'input_attrs' => array( 'style' => 'width: 50px;' )
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Border', array(
        'label' => esc_html__( 'Border Color', 'metz' ), 'description' => esc_html__( 'Only used if "Border Width" is higher than "0".', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_Border'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Header', array(
        'label' => esc_html__( 'Header Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Content', array(
        'label' => esc_html__( 'Content Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_DCB', array(
        'label' => esc_html__( 'Secondary Content Color', 'metz' ), 'description' => esc_html__( 'Used for date etc.', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_DCB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Link', array(
        'label' => esc_html__( 'Link Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_Link'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_RMBo', array(
        'label' => esc_html__( '"Read More" Border Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_RMBo'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_RMB', array(
        'label' => esc_html__( '"Read More" Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_RMB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_RMT', array(
        'label' => esc_html__( '"Read More" Text Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_RMT'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Teaser', array(
        'label' => esc_html__( 'Post Page Excerpt Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_Teaser'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Social', array(
        'label' => esc_html__( 'Icon Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_Social'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_InputText'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_BotSdw', array(
        'label' => esc_html__( 'Bottom Line Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_BotSdw'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_PostNavBackground', array(
        'label' => esc_html__( 'Post Navigation Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_PostNavBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_PostNavLink', array(
        'label' => esc_html__( 'Post Navigation Link Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Standard_PostNavLink'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_RMB', array(
        'label' => esc_html__( 'Page Navigation Button Background Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Site_RMB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_RMBo', array(
        'label' => esc_html__( 'Page Navigation Button Border Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Site_RMBo'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_RMT', array(
        'label' => esc_html__( 'Page Navigation Button Text Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Site_RMT'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_PageNumbers', array(
        'label' => esc_html__( 'Page Navigation Number Color', 'metz' ), 'section' => 'brnhmbx_sectionPostColors', 'settings' => 'brnhmbx_color_Site_PageNumbers'
	) ) );
	/* */

	$wp_customize->add_control( new metz_customTextAreaControl( $wp_customize, 'brnhmbx_text_CSS', array(
        'section' => 'brnhmbx_sectionCSS',
        'settings' => 'brnhmbx_text_CSS',
		'type' => 'text',
    ) ) );

	/* Google Maps */
	$wp_customize->add_control( 'brnhmbx_mapPage', array(
        'label' => esc_html__( 'Choose a Page', 'metz' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_mapPage',
		 'type' => 'dropdown-pages',
    ) );

	$wp_customize->add_control( 'brnhmbx_coorN', array(
        'label' => esc_html__( 'Coordinate N', 'metz' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_coorN',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_coorE', array(
        'label' => esc_html__( 'Coordinate E', 'metz' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_coorE',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_rng_MapZoom', array(
		'type'        => 'range',
		'section'     => 'brnhmbx_sectionGoogleMaps',
		'label'       => 'Zoom Level',
		'input_attrs' => array(
			'min'   => 5,
			'max'   => 19,
			'step'  => 1
		)
	) );

	$wp_customize->add_control( 'brnhmbx_mapHeight', array(
        'label' => esc_html__( 'Map Height', 'metz' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_mapHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Map', array(
        'label' => esc_html__( 'Show Map', 'metz' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_sh_Map',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_enableMapKey', array(
		'label' => esc_html__( 'Enable Map API Key', 'metz' ),
		'section' => 'brnhmbx_sectionGoogleMaps',
		'settings' => 'brnhmbx_enableMapKey',
		'type' => 'checkbox',
	) );
	$wp_customize->add_control( 'brnhmbx_mapAPI', array(
		'label' => esc_html__( 'API Key', 'metz' ),
		'description' => esc_html__( 'Only used if "Enable Map API Key" is checked.', 'metz' ),
		'section' => 'brnhmbx_sectionGoogleMaps',
		'settings' => 'brnhmbx_mapAPI',
		'type' => 'text',
	) );

	function metz_returnMapPageID( $input ) {

		if( is_numeric( $input ) ) {

			return intval( $input );

		}

	}
	/* */

	/* Banner Management // Since v.1.3 */
	$wp_customize->add_control( new metz_customTextAreaControl( $wp_customize, 'brnhmbx_text_Banner_1', array(
		'label' => esc_html__( 'Banner 1', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_text_Banner_1',
		'type' => 'text',
    ) ) );
	$wp_customize->add_control( new metz_customTextAreaControl( $wp_customize, 'brnhmbx_text_Banner_2', array(
		'label' => esc_html__( 'Banner 2', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_text_Banner_2',
		'type' => 'text',
    ) ) );
	$wp_customize->add_control( new metz_customTextAreaControl( $wp_customize, 'brnhmbx_text_Banner_3', array(
		'label' => esc_html__( 'Banner 3', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_text_Banner_3',
		'type' => 'text',
    ) ) );
	$wp_customize->add_control( 'brnhmbx_opt_BannerPos_1', array(
		'label' => esc_html__( '20.1. "Banner 1" Position', 'metz' ),
		'description' => esc_html__( 'Choose the placement for "Banner 1"', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_opt_BannerPos_1',
		'type' => 'radio',
		'choices' => array(
			'hidden' => 'Hidden',
			'above-full-slider' => 'Above Slider',
			'below-cover-slider' => 'Below Slider',
			'above-among-slider' => 'Above Slider (Among the Posts)',
			'below-among-slider' => 'Below Slider (Among the Posts)',
			'below-upper-widgets' => 'Below Upper Widgets',
			'below-blog-posts' => 'Below Blog Posts',
			'below-home-widgets' => 'Below Home Widgets',
			'below-post' => 'Post Pages (Below the Post)',
			'below-post-comments' => 'Post Pages (Below Post Comments)',
			'below-page' => 'Pages (Below the Page)',
			'below-page-comments' => 'Pages (Below Page Comments)'
		)
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_Banner_1_Archive', array(
        'label' => esc_html__( 'Show "Banner 1" on Archive Pages', 'metz' ),
		'description' => esc_html__( 'Only used if "Above Slider" or "Below Slider" is selected.', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_sh_Banner_1_Archive',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_Banner_1_Post', array(
        'label' => esc_html__( 'Show "Banner 1" on Post Pages', 'metz' ),
		'description' => esc_html__( 'Only used if "Above Slider" or "Below Slider" is selected.', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_sh_Banner_1_Post',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_opt_BannerPos_2', array(
		'label' => esc_html__( '20.2. "Banner 2" Position', 'metz' ),
		'description' => esc_html__( 'Choose the placement for "Banner 2"', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_opt_BannerPos_2',
		'type' => 'radio',
		'choices' => array(
			'hidden' => 'Hidden',
			'above-full-slider' => 'Above Slider',
			'below-cover-slider' => 'Below Slider',
			'above-among-slider' => 'Above Slider (Among the Posts)',
			'below-among-slider' => 'Below Slider (Among the Posts)',
			'below-upper-widgets' => 'Below Upper Widgets',
			'below-blog-posts' => 'Below Blog Posts',
			'below-home-widgets' => 'Below Home Widgets',
			'below-post' => 'Post Pages (Below the Post)',
			'below-post-comments' => 'Post Pages (Below Post Comments)',
			'below-page' => 'Pages (Below the Page)',
			'below-page-comments' => 'Pages (Below Page Comments)'
		)
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_Banner_2_Archive', array(
        'label' => esc_html__( 'Show "Banner 2" on Archive Pages', 'metz' ),
		'description' => esc_html__( 'Only used if "Above Slider" or "Below Slider" is selected.', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_sh_Banner_2_Archive',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_Banner_2_Post', array(
        'label' => esc_html__( 'Show "Banner 2" on Post Pages', 'metz' ),
		'description' => esc_html__( 'Only used if "Above Slider" or "Below Slider" is selected.', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_sh_Banner_2_Post',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_opt_BannerPos_3', array(
		'label' => esc_html__( '20.3. "Banner 3" Position', 'metz' ),
		'description' => esc_html__( 'Choose the placement for "Banner 3"', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_opt_BannerPos_3',
		'type' => 'radio',
		'choices' => array(
			'hidden' => 'Hidden',
			'above-full-slider' => 'Above Slider',
			'below-cover-slider' => 'Below Slider',
			'above-among-slider' => 'Above Slider (Among the Posts)',
			'below-among-slider' => 'Below Slider (Among the Posts)',
			'below-upper-widgets' => 'Below Upper Widgets',
			'below-blog-posts' => 'Below Blog Posts',
			'below-home-widgets' => 'Below Home Widgets',
			'below-post' => 'Post Pages (Below the Post)',
			'below-post-comments' => 'Post Pages (Below Post Comments)',
			'below-page' => 'Pages (Below the Page)',
			'below-page-comments' => 'Pages (Below Page Comments)'
		)
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_Banner_3_Archive', array(
        'label' => esc_html__( 'Show "Banner 3" on Archive Pages', 'metz' ),
		'description' => esc_html__( 'Only used if "Above Slider" or "Below Slider" is selected.', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_sh_Banner_3_Archive',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_Banner_3_Post', array(
        'label' => esc_html__( 'Show "Banner 3" on Post Pages', 'metz' ),
		'description' => esc_html__( 'Only used if "Above Slider" or "Below Slider" is selected.', 'metz' ),
        'section' => 'brnhmbx_sectionBanner',
        'settings' => 'brnhmbx_sh_Banner_3_Post',
		'type' => 'checkbox'
    ) );
	/* */

}
add_action( 'customize_register', 'metz_customizeAppearance' );
?>
