<?php

if ( !isset( $content_width ) ) {

	$content_width = 2560;

}

/* Include Customizer */
include( 'customizer.php' );
/* */

/* Load Widgets Filter */
if ( !function_exists( 'metz_customLoadWidgets' ) ) {
	function metz_customLoadWidgets() {

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'underscore' );

	}
}
add_action( 'load-widgets.php', 'metz_customLoadWidgets' );
/* */

/* Google Fonts */
include( get_template_directory() . '/lib/google-fonts.php' );

if ( !function_exists( 'metz_fonts_url' ) ) {
	function metz_fonts_url() {

		$font_customizer_names = array();

		foreach ( metz_font_labels() as $key => $val ) {

			$add_underscore = str_replace( ' ', '_', $key );
			$font_customizer_names[ $add_underscore ] = $key . ':300,300i,400,400i,700,700i';

		}

		$font_holders = array(
			get_theme_mod( 'metz2017_font_primary', 'Playfair_Display' ),
			get_theme_mod( 'metz2017_font_secondary', 'Arial' )
		);

		$font_families = array();

		foreach ( $font_customizer_names as $n => $g ) {
			foreach ( $font_holders as $fh ) {
				if( $n == $fh ) {
					if ( !in_array( $g, $font_families ) ) {
						$font_families[] = $g;
					}
				}
			}
		}

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
		);

		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
		return esc_url_raw( $fonts_url );

	}
}
/* */

/* Embed Resources */
if ( !function_exists( 'metz_embedResources' ) ) {
	function metz_embedResources() {

		global $post;

		wp_enqueue_style( 'metz-fonts', metz_fonts_url(), array(), null );

		wp_enqueue_style( 'reset', get_template_directory_uri() . '/css/reset.css', array( 'metz-fonts' ) );
		wp_enqueue_style( 'metz-style', get_stylesheet_uri() );
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '4.3.0', 'all' );
		wp_enqueue_style( 'metz-montserrat', '//fonts.googleapis.com/css?family=Montserrat&subset=latin' );

		/* */

		if ( !is_page() || has_shortcode( $post->post_content, 'metzslider' ) || has_shortcode( $post->post_content, 'new_metzslider' ) ) {

			wp_enqueue_style( 'bxslider', get_template_directory_uri() . '/css/jquery.bxslider.css', array(), '', 'all' );

		}

		wp_enqueue_style( 'metz-responsive', get_template_directory_uri() . '/css/responsive.css', array(), '', 'all' );
		wp_enqueue_style( 'slicknav', get_template_directory_uri() . '/css/slicknav.css', array(), '', 'all' );
		wp_add_inline_style( 'slicknav', metz_rewriteCSS() );

		/* */

		wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '', true );

		if ( !is_page() || has_shortcode( $post->post_content, 'metzslider' ) || has_shortcode( $post->post_content, 'new_metzslider' ) ) {

			wp_enqueue_script( 'bxslider', get_template_directory_uri() . '/js/jquery.bxslider.min.js', array( 'jquery' ), '', true );
			wp_enqueue_script( 'metz-burnhambox-bx-js', get_template_directory_uri() . '/js/burnhambox-bx.js', array( 'jquery' ), '', true );

		}

		wp_enqueue_script( 'metz-burnhambox-js', get_template_directory_uri() . '/js/burnhambox.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/js/jquery.slicknav.min.js', array( 'jquery' ), '', true );

		if ( is_page() && get_theme_mod( 'brnhmbx_sh_Map' ) && get_theme_mod( 'brnhmbx_mapPage' ) == get_the_ID() ) {

			if ( get_theme_mod( 'brnhmbx_enableMapKey', 0 ) ) { wp_enqueue_script( 'metz-maps-api', '//maps.googleapis.com/maps/api/js?key=' . esc_attr( get_theme_mod( 'brnhmbx_mapAPI', '' ) ), array(), '', false ); } else { wp_enqueue_script( 'metz-maps-api', '//maps.googleapis.com/maps/api/js', array(), '', false ); }

			wp_enqueue_script( 'metz-maps-js', get_template_directory_uri() . '/js/maps.js', array( 'jquery' ), '', true );

		}

	}
}
add_action( 'wp_enqueue_scripts', 'metz_embedResources' );
/* */

/* Detect WooCommerce Plugin */
$brnhmbx_woo_plugin = false;

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if ( function_exists( 'WC' ) ) {

  $brnhmbx_woo_plugin = true;

}
/* */

/* Theme setup */
if ( !function_exists( 'metz_themeSetup' ) ) {
	function metz_themeSetup() {

		// Navigation Menu
		register_nav_menus( array(

			'primary' => esc_html__( 'Primary Menu', 'metz' ),
			'footer_menu' => esc_html__( 'Footer Menu', 'metz' ),
			'header_menu' => esc_html__( 'Header Menu', 'metz' )

		) );

		// If "Crop Images" is set
		$brnhmbx_imageWidth = 1080;
		$brnhmbx_imageHeight = '';
		$brnhmbx_homeImageHeight = get_theme_mod( 'brnhmbx_homeImageHeight', 310 );
		$brnhmbx_sliderWidth = 1080;
		$brnhmbx_sliderHeight = 500;

		if  ( get_theme_mod( 'brnhmbx_imageWidth' ) ) {

			$brnhmbx_imageWidth = get_theme_mod( 'brnhmbx_imageWidth', 1080 );

		}

		if  ( get_theme_mod( 'brnhmbx_imageHeight' ) ) {

			$brnhmbx_imageHeight = get_theme_mod( 'brnhmbx_imageHeight', 0 );

		}

		if  ( get_theme_mod( 'brnhmbx_sliderWidth' ) ) {

			$brnhmbx_sliderWidth = get_theme_mod( 'brnhmbx_sliderWidth', 1080 );

		}

		if  ( get_theme_mod( 'brnhmbx_sliderHeight' ) ) {

			$brnhmbx_sliderHeight = get_theme_mod( 'brnhmbx_sliderHeight', 500 );

		}

		// Add featured image support. Works for only new added images.
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( esc_attr( $brnhmbx_imageWidth ), esc_attr( $brnhmbx_imageHeight ), true ); // Featured Image
		add_image_size( 'slider-image', esc_attr( $brnhmbx_sliderWidth ), esc_attr( $brnhmbx_sliderHeight ), array( 'center', 'top' ) ); // Slider Images
		add_image_size( 'brnhmbx-metz-slider-thumbnail-image', 150, 100, array( 'center', 'top' ) ); // Slider Small Thumbnails
		add_image_size( 'related-thumbnail', 600, 400, array( 'center', 'top' ) ); // Related Posts Thumbnails
		add_image_size( 'page-navigation-thumbnail', 80, 80, array( 'center', 'top' ) ); // Page Navigation Thumbnails
		add_image_size( 'home-thumbnail', 720, esc_attr( $brnhmbx_homeImageHeight ), array( 'center', 'top' ) ); // Home Thumbnails

		// Add post type support
		add_theme_support( 'post-formats', array( 'gallery', 'video', 'aside', 'link' ) );

		// Add automatic feed links support
		add_theme_support( 'automatic-feed-links' );

		// Add title-tag support
		add_theme_support( 'title-tag' );

		// Add text-domain
		load_theme_textdomain( 'metz', get_template_directory() . '/languages ');

		// Add WooCommerce support
		// Since v.1.1
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

		// Add wide images support for Gutenberg
		add_theme_support( 'align-wide' );

	}
}
add_action( 'after_setup_theme', 'metz_themeSetup' );
/* */

/* Related Products Count */
if ( !function_exists( 'metz_related_products_args' ) ) {
	function metz_related_products_args( $args ) {

		$args['posts_per_page'] = 4;
		$args['columns'] = 2;
		return $args;

	}
}
add_filter( 'woocommerce_output_related_products_args', 'metz_related_products_args' );
/* */

/* WooCommerce change number or products per row */
if ( !function_exists( 'metz_loop_columns' ) ) {

	function metz_loop_columns() {

		return 2;

	}

}
add_filter( 'loop_shop_columns', 'metz_loop_columns' );
/* */

/* Change number of products displayed per page */
if ( !function_exists( 'metz_products_per_page' ) ) {
	function metz_products_per_page() {

		$product_count = esc_attr( get_theme_mod( 'brnhmbx_productPerPage', '6' ) );
		return $product_count;

	}
}
if ( function_exists( 'WC' ) ) {
	add_filter( 'loop_shop_per_page', 'metz_products_per_page', 20 );
}
/* */

/* Find all galleries and make them slider. */
if ( !function_exists( 'metz_check_gutenberg_gallery' ) ) {
	function metz_check_gutenberg_gallery() {

		global $post, $gutenberg_first_image;

		$image_list = '';

		$doc = new DOMDocument();
		libxml_use_internal_errors( true );
		$doc->loadHTML( $post->post_content );
		$xpath = new DOMXPath( $doc );

		$first = true;
		foreach ( $xpath->query('//li[@class="blocks-gallery-item"]/figure/img/@src') as $attr ) {

		  $src = $attr->value;

			if ( $first ) {
				$gutenberg_first_image = $src;
				$first = false;
			}

			$image_list .= '<li><img alt="theme-img-alt" src="' . esc_url( $src ) . '"></li>';

		}

		if ( $image_list ) {

			$image_list = '<ul class="bxslider">' . $image_list;
			$image_list .= '</ul>';

		}

		return $image_list;

	}
}

if ( !function_exists( 'metz_galleryToSlider' ) ) {
	function metz_galleryToSlider( $content ) {

		global $post;

			// Make sure the post format is gallery
			if ( !has_post_format( 'gallery' ) ) {

				return $content;

			}

			// Make sure the post has a gallery in it
			if ( !has_shortcode( $post->post_content, 'gallery' ) ) {

				if ( metz_check_gutenberg_gallery() ) {

					echo metz_check_gutenberg_gallery();

				} else {

					return $content;

				}

			} else {

				// Retrieve the galleries in the post
				$galleries = get_post_galleries_images( $post );

				$image_list = '<ul class="bxslider">';

				// Loop through all galleries found
				foreach( $galleries as $gallery ) {

					// Loop through each image in each gallery
					foreach( $gallery as $image_url ) {

						$image_list .= '<li><img alt="theme-img-alt" src="' . esc_url( $image_url ) . '"></li>';

					}

				}

				$image_list .= '</ul>';

				return $image_list;

			}

	}
}
/* */

/* Get the first image of the post/gallery */
if ( !function_exists( 'metz_getTheFirstImage' ) ) {
	function metz_getTheFirstImage() {

		global $post;

			$image_list = '';
			$first_img = '';
			$firstBo = true;
			ob_start();
			ob_end_clean();

			// Retrieve the galleries in the post
			$galleries = get_post_galleries_images( $post );

			// Check if has a gallery
			if ( $galleries ) {

				// Loop through all galleries found
				foreach( $galleries as $gallery ) {

					// Loop through each image in each gallery
					foreach( $gallery as $image_url ) {

						$image_list = $image_url;

						if ( $firstBo ) {

							$first_img = $image_list;
							$firstBo = false;

						}

					}

				}

				if ( empty( $first_img ) ) {

					$first_img = 'none';

				}

				return $first_img;

			} else if ( metz_check_gutenberg_gallery() ) {

				// Gutenberg gallery block check
				metz_check_gutenberg_gallery();
				global $gutenberg_first_image;
				return $gutenberg_first_image;

			} else {

				// Has no gallery, check if has an image
				$output = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches );

				if ( $output ) {

					$first_img = $matches[1][0];

				} else {

					$first_img = 'none';

				}

				return $first_img;

			}

	}
}
/* */

/* Clear White Space */
if ( !function_exists( 'metz_compress' ) ) {
	function metz_compress( $buffer ) {

		$buffer = preg_replace( '~>\s+<~', '><', $buffer );
		return $buffer;

	}
}
/* */

/* Content Filter */
if ( !function_exists( 'metz_filterContent' ) ) {
	function metz_filterContent( $content ) {

	 	global $post;

		// Add bxslider-vid class to iframes to make the videos responsive in posts
		$content = preg_replace( array( '{<iframe}', '{</iframe>}' ), array( '<ul class="bxslider-vid"><li><iframe', '</iframe></li></ul>' ), $content );

		return $content;

	}
}
add_filter( 'the_content', 'metz_filterContent' );
/* */

/* Add responsive container to embeds for wordpress.tv */
if ( !function_exists( 'metz_embed_html' ) ) {
	function metz_embed_html( $html ) {

		$html = preg_replace( array( '{<embed src="//v.wordpress}', '{wmode="transparent">}' ), array( '<div class="video-container"><embed src="//v.wordpress', 'wmode="transparent"></div>' ), $html );

	    return $html;

	}
}
add_filter( 'embed_oembed_html', 'metz_embed_html', 10, 3 );
/* */

/* Find all videos and make them slider */
if ( !function_exists( 'metz_videoToSlider' ) ) {
	function metz_videoToSlider() {

		global $post;

			$result = '';
			ob_start();
			ob_end_clean();
			$output = preg_match_all( '/\[embed(.*)](.*)\[\/embed]/', $post->post_content, $matches );
			$output_gutenberg = preg_match_all( "'<figure class=\"(.*?)is-type-video(.*?)\">(.*?)</figure>'si", $post->post_content, $matches_gutenberg );


			// Make sure the post has a video in it
			if ( $output || $output_gutenberg ) {

				$result = '<ul class="bxslider bxslider-vid">';

			} else {

				$result = 'none';

			}

			if ( $output ) {

				// Replace/remove/add necessary things for Vimeo and YouTube
				for( $i = 0; $i < $output; $i++ ) {

					$result .= '<li>' . preg_replace( array( '/\[embed]/', '/\[\/embed]/', '{https://vimeo.com}', '{watch?.*?v=}', '/&#.*? /' ), array( '<iframe style="border: none;" src="', ' " width="500" height="281" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>', '//player.vimeo.com/video', 'embed/', '?enablejsapi=1' ), esc_attr( $matches[0][$i] ) ) . '</li>';

				}

			}

			if ( $output_gutenberg ) {

				// Replace/remove/add necessary things for Vimeo and YouTube
				for( $j = 0; $j < $output_gutenberg; $j++ ) {

					$result .= '<li>' . preg_replace( array( '/&lt;figure class=&quot;(.*?)is-type-video(.*?)&quot;&gt;/', '/&lt;div class=&quot;(.*?)wp-block-embed__wrapper(.*?)&quot;&gt;/', '/&lt;\/div&gt;/', '/&lt;\/figure&gt;/', '{https://vimeo.com}', '{watch?.*?v=}', '/&#.*? /' ), array( '<iframe style="border: none;" src="', '', '', ' " width="500" height="281" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>', '//player.vimeo.com/video', 'embed/', '?enablejsapi=1' ), esc_attr( $matches_gutenberg[0][$j] ) ) . '</li>';

				}

			}

			if ( $output || $output_gutenberg ) {

				$result .= '</ul>';

			}

			return $result;

	}
}
/* */

/* Remove embed and gallery tags */
if ( !function_exists( 'metz_clearEmbeds' ) ) {
	function metz_clearEmbeds() {

		$replaceEmbeddedVideo = '/\<ul class="bxslider-vid"(.*)\<\/ul>/';

		$result = preg_replace(
			array( $replaceEmbeddedVideo ),
			array( '' ),
			metz_formatGetTheContent() );

		return $result;

	}
}
/* */

/* Formatting the content like "the_content" while using "get_the_content" */
if ( !function_exists( 'metz_formatGetTheContent' ) ) {
	function metz_formatGetTheContent( $more_link_text = null, $stripteaser = false ) {

		$content = get_the_content( $more_link_text, $stripteaser );
		$content = apply_filters( 'the_content', $content );
		return $content;

	}
}
/* */

/* Combine Listing Styles */
if ( !function_exists( 'metz_callPostOrder' ) ) {
	function metz_callPostOrder() {

		//Call the post order in the loop
		global $brnhmbx_counter;
		return $brnhmbx_counter;

	}
}

if ( !function_exists( 'metz_checkStyle_A' ) ) {
	function metz_checkStyle_A() {

		$brnhmbx_postPerPage = get_option( 'posts_per_page' );
		$brnhmbx_styleA_count = get_theme_mod( 'brnhmbx_styleA_count', 0 );
		$brnhmbx_styleB_count = get_theme_mod( 'brnhmbx_styleB_count', 0 );

		if ( $brnhmbx_styleA_count + $brnhmbx_styleB_count > $brnhmbx_postPerPage ) {

			$brnhmbx_styleA_count = 0;

		}

		$brnhmbx_postOrder = metz_callPostOrder();
		$brnhmbx_postOrder ++;
		$brnhmbx_styleA_boo = false;

		if ( $brnhmbx_styleA_count == 0 || is_single() ) {

			$brnhmbx_styleA_boo = false;

		} else {

			if ( $brnhmbx_postOrder > $brnhmbx_postPerPage - ( $brnhmbx_styleA_count + $brnhmbx_styleB_count ) && $brnhmbx_postOrder <= $brnhmbx_postPerPage - $brnhmbx_styleB_count ) {

				$brnhmbx_styleA_boo = true;

			}

		}

		return $brnhmbx_styleA_boo;

	}
}

if ( !function_exists( 'metz_checkStyle_B' ) ) {
	function metz_checkStyle_B() {

		$brnhmbx_postPerPage = get_option( 'posts_per_page' );
		$brnhmbx_styleA_count = get_theme_mod( 'brnhmbx_styleA_count', 0 );
		$brnhmbx_styleB_count = get_theme_mod( 'brnhmbx_styleB_count', 0 );

		if ( $brnhmbx_styleA_count + $brnhmbx_styleB_count > $brnhmbx_postPerPage ) {

			$brnhmbx_styleB_count = 0;

		}

		$brnhmbx_postOrder = metz_callPostOrder();
		$brnhmbx_postOrder ++;
		$brnhmbx_styleB_boo = false;

		if ( $brnhmbx_styleB_count == 0 || is_single() ) {

			$brnhmbx_styleB_boo = false;

		} else {

			if ( $brnhmbx_postOrder > $brnhmbx_postPerPage - $brnhmbx_styleB_count ) {

				$brnhmbx_styleB_boo = true;

			}

		}

		if ( is_search() ) {

			$brnhmbx_styleB_boo = true;

		}

		return $brnhmbx_styleB_boo;

	}
}
/* */

/* Set "Read More" button */
if ( !function_exists( 'metz_setMoreButton' ) ) {
	function metz_setMoreButton() {

		$brnhmbx_tra_ReadMore = esc_html__( 'READ MORE', 'metz' );

		if ( get_theme_mod( 'metz_ignorePot', 1 ) ) {

			$brnhmbx_tra_ReadMore = get_theme_mod( 'brnhmbx_tra_ReadMore', 'READ MORE' );

		}

		global $post;

		if ( get_theme_mod( 'brnhmbx_sh_btnReadMore', 1 ) ) {

			if( !strstr( $post->post_content, '<!--more-->' ) ) {

				return '...<div class="btnReadMore pt20 bButton"><a href="'. esc_url( get_permalink( get_the_ID() ) ) . '">' . esc_attr( $brnhmbx_tra_ReadMore ) . '</a></div>';

			}

		}

	}
}
add_filter( 'excerpt_more', 'metz_setMoreButton' );
/* */

/* Append "Read More" button */
if ( !function_exists( 'metz_appendMoreButton' ) ) {
	function metz_appendMoreButton() {

		$brnhmbx_tra_ReadMore = esc_html__( 'READ MORE', 'metz' );

		if ( get_theme_mod( 'metz_ignorePot', 1 ) ) {

			$brnhmbx_tra_ReadMore = get_theme_mod( 'brnhmbx_tra_ReadMore', 'READ MORE' );

		}

		global $post;

		if ( get_theme_mod( 'brnhmbx_sh_Excerpt', 1 ) ) {

			if( strstr( $post->post_content, '<!--more-->' ) ) {

				echo '<div class="fs16 playfair the-content clearfix home-excerpt home-content-padding">';
				$excerpt = get_the_excerpt();

				if ( get_theme_mod( 'brnhmbx_sh_btnReadMore', 1 ) ) {

					echo wp_kses_post( $excerpt ) . '<div class="btnReadMore pt20 bButton"><a href="'. esc_url( get_permalink() ) .'">' . esc_attr( $brnhmbx_tra_ReadMore ) . '</a></div></div>';

				}

			} else {

				if ( $post->post_excerpt ) {

					echo '<div class="fs16 playfair the-content clearfix home-excerpt home-content-padding">';
					$excerpt = get_the_excerpt();

					if ( get_theme_mod( 'brnhmbx_sh_btnReadMore', 1 ) ) {

						echo wp_kses_post( $excerpt ) . '<div class="btnReadMore pt20 bButton"><a href="'. esc_url( get_permalink() ) .'">' . esc_attr( $brnhmbx_tra_ReadMore ) . '</a></div></div>';

					} else {

						echo wp_kses_post( $excerpt ) . '</div>';

					}

				} else {

					echo '<div class="fs16 playfair the-content clearfix home-excerpt home-content-padding">';
					//the_excerpt();
					echo get_the_excerpt();
					echo '</div>';

				}

			}

		}

	}
}
/* */

/* Apply layout options */
if ( !function_exists( 'metz_applyLayout' ) ) {
	function metz_applyLayout() {

		/* Radio Default Values */
		$brnhmbx_opt_Layout = get_theme_mod( 'brnhmbx_opt_Layout', '2col_sidebar' );
		$brnhmbx_opt_Layout_Archive = get_theme_mod( 'brnhmbx_opt_Layout_Archive', '2col_sidebar' );
		/* */

		$layout = '';
		global $brnhmbx_woo_plugin;

		if ( $brnhmbx_woo_plugin && function_exists( 'is_woocommerce' ) && is_woocommerce() && !is_page() ) {

			$brnhmbx_sh_SidebarShop = get_theme_mod( 'brnhmbx_sh_SidebarShop', 1 );
			$brnhmbx_sh_SidebarProduct = get_theme_mod( 'brnhmbx_sh_SidebarProduct', 1 );
			$layout = '';

			if ( ( is_shop() || is_product_category() || is_product_tag() ) && $brnhmbx_sh_SidebarShop ) { $layout = '-sidebar'; }
			if ( is_product() && $brnhmbx_sh_SidebarProduct ) { $layout = '-sidebar'; }

		} else if ( is_single() ) {

			if ( !is_attachment() ) {

				if ( ( get_post_format() == '' || get_post_format() == 'aside' || get_post_format() == 'link' ) && get_theme_mod( 'brnhmbx_sh_SidebarPost_Standard', 1 ) ) {

					// Show sidebar at standard posts
					$layout = '-sidebar';

				} else if ( get_post_format() == 'gallery' && get_theme_mod( 'brnhmbx_sh_SidebarPost_Gallery', 1 ) ) {

					// Show sidebar at gallery posts
					$layout = '-sidebar';

				} else if ( get_post_format() == 'video' && get_theme_mod( 'brnhmbx_sh_SidebarPost_Video', 1 ) ) {

					// Show sidebar at video posts
					$layout = '-sidebar';

				}

			}

		} else if ( is_category() || is_author() || is_tag() || is_archive() || is_search() ) {

			if ( $brnhmbx_opt_Layout_Archive == '1col' ) {

				// No sidebar
				$layout = '';

			} else if ( $brnhmbx_opt_Layout_Archive == '2col' ) {

				// 2 columns //-c(olumn)c(ount)2
				$layout = '-cc2';

			} else if ( $brnhmbx_opt_Layout_Archive == '3col' || $brnhmbx_opt_Layout_Archive == '2_3col' ) {

				// 3 columns //-c(olumn)c(ount)3
				$layout = '-cc3';

			} else if ( $brnhmbx_opt_Layout_Archive == '1col_sidebar' ) {

				// Columns + Sidebar
				$layout = '-sidebar';

			} else if ( $brnhmbx_opt_Layout_Archive == '2col_sidebar' || $brnhmbx_opt_Layout_Archive == '1_2col_sidebar' ) {

				// Columns + Sidebar
				$layout = '-sidebar-cc2';

			}

		} else if ( is_page() ) {

			if ( $brnhmbx_woo_plugin && function_exists( 'is_cart' ) && ( is_cart() || is_account_page() || is_checkout() ) ) {

				$layout = '';

			} else {

				if ( get_theme_mod( 'brnhmbx_sh_SidebarInnerPage', 1 ) ) {

					// Show sidebar at inner pages
					$layout = '-sidebar';

				}

			}

		} else if ( is_404() ) {

			$layout = '';

		} else {

			if ( $brnhmbx_opt_Layout == '1col' ) {

				// No sidebar
				$layout = '';

			} else if ( $brnhmbx_opt_Layout == '2col' ) {

				// 2 columns //-c(olumn)c(ount)2
				$layout = '-cc2';

			} else if ( $brnhmbx_opt_Layout == '3col' || $brnhmbx_opt_Layout == '2_3col' ) {

				// 3 columns //-c(olumn)c(ount)3
				$layout = '-cc3';

			} else if ( $brnhmbx_opt_Layout == '1col_sidebar' ) {

				// Columns + Sidebar
				$layout = '-sidebar';

			} else if ( $brnhmbx_opt_Layout == '2col_sidebar' || $brnhmbx_opt_Layout == '1_2col_sidebar' ) {

				// Columns + Sidebar
				$layout = '-sidebar-cc2';

			}

		}

		return $layout;

	}
}
/* */

/* Apply column options */
if ( !function_exists( 'metz_applyColumns' ) ) {
	function metz_applyColumns() {

		/* Radio Default Values */
		$brnhmbx_opt_Layout = get_theme_mod( 'brnhmbx_opt_Layout', '2col_sidebar' );
		$brnhmbx_opt_Layout_Archive = get_theme_mod( 'brnhmbx_opt_Layout_Archive', '2col_sidebar' );
		/* */

		$column = '';

		if ( is_category() || is_author() || is_tag() || is_archive() || is_search() ) {

			if ( $brnhmbx_opt_Layout_Archive == '1col' ) {

				// No sidebar
				$column = '';

			} else if ( $brnhmbx_opt_Layout_Archive == '2col' ) {

				// 2 Columns (No sidebar)
				$column = 'col-1-2';

			} else if ( $brnhmbx_opt_Layout_Archive == '3col' || $brnhmbx_opt_Layout_Archive == '2_3col' ) {

				// 3 Columns (No sidebar)
				$column = 'col-1-3';

			} else if ( $brnhmbx_opt_Layout_Archive == '1col_sidebar' ) {

				// 1 Column + Sidebar
				$column = '';

			} else if ( $brnhmbx_opt_Layout_Archive == '2col_sidebar' || $brnhmbx_opt_Layout_Archive == '1_2col_sidebar' ) {

				// 2 Columns + Sidebar
				$column = 'col-1-2-sidebar';

			}

		} else {

			if ( $brnhmbx_opt_Layout == '1col' ) {

				// No sidebar
				$column = '';

			} else if ( $brnhmbx_opt_Layout == '2col' ) {

				// 2 Columns (No sidebar)
				$column = 'col-1-2';

			} else if ( $brnhmbx_opt_Layout == '3col' || $brnhmbx_opt_Layout == '2_3col' ) {

				// 3 Columns (No sidebar)
				$column = 'col-1-3';

			} else if ( $brnhmbx_opt_Layout == '1col_sidebar' ) {

				// 1 Column + Sidebar
				$column = '';

			} else if ( $brnhmbx_opt_Layout == '2col_sidebar' || $brnhmbx_opt_Layout == '1_2col_sidebar' ) {

				// 2 Columns + Sidebar
				$column = 'col-1-2-sidebar';

			}

		}

		return $column;

	}
}
/* */

/* Pagination */
if ( !function_exists( 'metz_Pagination' ) ) {
	function metz_Pagination() {

		global $wp_query, $indexPosts;

		$brnhmbx_big = 999999999; // need an unlikely integer

		if ( get_theme_mod( 'brnhmbx_bptsExclude', '0' ) ) {

			if ( is_home() ) {

				$brnhmbx_current_query_mnp = $indexPosts->max_num_pages;

			} else {

				$brnhmbx_current_query_mnp = $wp_query->max_num_pages;

			}

		} else {

			$brnhmbx_current_query_mnp = $wp_query->max_num_pages;

		}

		$brnhmbx_tra_NewerPosts = esc_html__( 'NEWER POSTS', 'metz' );
		$brnhmbx_tra_OlderPosts = esc_html__( 'OLDER POSTS', 'metz' );

		if ( get_theme_mod( 'metz_ignorePot', 1 ) ) {

			$brnhmbx_tra_NewerPosts = get_theme_mod( 'brnhmbx_tra_NewerPosts', 'NEWER POSTS' );
			$brnhmbx_tra_OlderPosts = get_theme_mod( 'brnhmbx_tra_OlderPosts', 'OLDER POSTS' );

		}

		$brnhmbx_paginate_links = paginate_links( array(

			'base' => str_replace( $brnhmbx_big, '%#%', esc_url( get_pagenum_link( $brnhmbx_big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, get_query_var( 'paged' ) ),
			'total' => $brnhmbx_current_query_mnp,
			'prev_text'          => esc_attr( $brnhmbx_tra_NewerPosts ),
			'next_text'          => esc_attr( $brnhmbx_tra_OlderPosts ),
			'before_page_number' => '<span class="page-number-inner">',
			'after_page_number' => '</span>',
			'end_size'           => 1,
			'mid_size'           => 1

		) );

		if ( $brnhmbx_paginate_links ) {

			echo '<div class="pagenavi clearfix';

			if ( get_query_var( 'paged' ) <= 1 ) {

				echo ' pagenavi-fp';

			} else if ( get_query_var( 'paged' ) == $brnhmbx_current_query_mnp ) {

				echo ' pagenavi-lp';

			}

			echo '">';
			echo wp_kses_post( $brnhmbx_paginate_links );
			echo '</div>';

		}

	}
}
/* */

if ( !function_exists( 'metz_ourWidgetsInit' ) ) {
	function metz_ourWidgetsInit() {

		/* Get footer widgets column number */
		$fw_col_number = '';
		$hw_col_number = '';
		$uw_col_number = '';
		$hew_col_number = '';

		if ( !get_theme_mod( 'brnhmbx_use3ColFooter', 1 ) ) {

			$fw_col_number = '-col2';

		}

		if ( !get_theme_mod( 'brnhmbx_use3ColHome', 0 ) ) {

			$hw_col_number = '-col2';

		}

		if ( !get_theme_mod( 'brnhmbx_use3ColUpper', 0 ) ) {

			$uw_col_number = '-col2';

		}

		if ( !get_theme_mod( 'brnhmbx_headerWidgetsCol', 0 ) ) {

			$hew_col_number = '-col2';

		}

		//If layout has sidebar, go for -col2-sidebar
		if ( get_theme_mod( 'brnhmbx_opt_Layout', '2col_sidebar' ) == '1col_sidebar' || get_theme_mod( 'brnhmbx_opt_Layout', '2col_sidebar' ) == '2col_sidebar' || get_theme_mod( 'brnhmbx_opt_Layout', '2col_sidebar' ) == '1_2col_sidebar' ) {

			$hw_col_number = '-col2-sidebar';
			$uw_col_number = '-col2-sidebar';

		}

		/* */

		// Add Widget Areas
		register_sidebar( array(
			'name' => 'Sidebar',
			'id' => 'brnhmbx_sidebar_right',
			'before_widget' => '<div class="widget-item zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div>',
		) );

		// Since v.1.5
		register_sidebar( array(
			'name' => 'Sidebar - Archive',
			'id' => 'brnhmbx_sidebar_archive',
			'before_widget' => '<div class="widget-item zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div>',
		) );

		register_sidebar( array(
			'name' => 'Sidebar - Page',
			'id' => 'brnhmbx_sidebar_page',
			'before_widget' => '<div class="widget-item zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div>',
		) );

		register_sidebar( array(
			'name' => 'Sidebar - Post',
			'id' => 'brnhmbx_sidebar_post',
			'before_widget' => '<div class="widget-item zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div>',
		) );
		//

		register_sidebar( array(
			'name' => 'Footer Widgets',
			'id' => 'brnhmbx_footer_widgets',
			'before_widget' => '<div class="widget-item-footer-outer' . esc_attr( $fw_col_number ) . '"><div class="widget-item-footer zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div></div>',
		) );

		register_sidebar( array(
			'name' => 'Home Widgets',
			'id' => 'brnhmbx_home_widgets',
			'before_widget' => '<div class="widget-item-home-outer' . esc_attr( $hw_col_number ) . '"><div class="widget-item zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div></div>',
		) );

		// Since v.1.1
		register_sidebar( array(
			'name' => 'WooCommerce Widgets',
			'id' => 'brnhmbx_woo_widgets',
			'before_widget' => '<div id="%1$s" class="widget-item zig-zag clearfix %2$s"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div>',
		) );

		// Since v.1.2
		register_sidebar( array(
			'name' => 'Upper Widgets',
			'id' => 'brnhmbx_upper_widgets',
			'before_widget' => '<div class="widget-item-upper-outer' . esc_attr( $uw_col_number ) . '"><div class="widget-item zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div></div>',
		) );

		register_sidebar( array(
			'name' => 'Header Widgets',
			'id' => 'brnhmbx_header_widgets',
			'before_widget' => '<div class="widget-item-header-outer' . esc_attr( $hew_col_number ) . '"><div class="widget-item zig-zag clearfix"><div class="fs14 arial widget-item-inner">',
			'before_title' => '<h2 class="playfair">',
			'after_title' => '</h2>',
			'after_widget' => '</div></div></div>',
		) );

	}
}
add_action( 'widgets_init', 'metz_ourWidgetsInit' );

/* HEX to RGB */
if ( !function_exists( 'metz_hex2rgb' ) ) {
	function metz_hex2rgb( $hex ) {

		$hex = str_replace( '#', '', $hex );

		if ( strlen( $hex ) == 3 ) {

			$r = hexdec( substr( $hex, 0, 1 ).substr( $hex, 0, 1 ) );
			$g = hexdec( substr( $hex, 1, 1).substr( $hex, 1, 1 ) );
			$b = hexdec( substr( $hex, 2, 1).substr( $hex, 2, 1 ) );

		} else {

			$r = hexdec( substr( $hex, 0, 2 ) );
			$g = hexdec( substr( $hex, 2, 2 ) );
			$b = hexdec( substr( $hex, 4, 2 ) );

		}

		$rgb = array( $r, $g, $b );
		return implode( ',', $rgb ); // returns the rgb values separated by commas

	}
}
/* */

/* Place Slider */
if ( !function_exists( 'metz_placeSlider' ) ) {
	function metz_placeSlider() {

		$sliderShortcode = get_theme_mod( 'brnhmbx_sliderShortcode', '' );
		global $brnhmbx_woo_plugin;

		if ( $brnhmbx_woo_plugin && function_exists( 'is_woocommerce' ) && is_woocommerce() ) {

			//Hide Slider

		} else {

			if ( $sliderShortcode ) {

				if ( is_home() ) {

					if ( get_theme_mod( 'brnhmbx_opt_SliderHomeView', 'home-all' ) == 'home-all' ) {

						echo do_shortcode( esc_attr( $sliderShortcode ) );

					} else if ( get_theme_mod( 'brnhmbx_opt_SliderHomeView', 'home-all' ) == 'home-front' && get_query_var( 'paged' ) <= 1 ) {

						echo do_shortcode( esc_attr( $sliderShortcode ) );

					} else if ( get_theme_mod( 'brnhmbx_opt_SliderHomeView', 'home-all' ) == 'home-hide' ) {

						//Hide Slider

					}

				}

				if ( is_archive() && get_theme_mod( 'brnhmbx_sh_SliderArchive', 0 ) ) {

					echo do_shortcode( esc_attr( $sliderShortcode ) );

				}

				if ( is_single() && get_theme_mod( 'brnhmbx_sh_SliderPost', 0 ) ) {

					echo do_shortcode( esc_attr( $sliderShortcode ) );

				}

			}

		}

	}
}
/* */

/* Customize Default Tag Cloud Widget */
if ( !function_exists( 'metz_defaultTagCloud' ) ) {
	function metz_defaultTagCloud( $args ) {

		$args['largest'] = 15; //largest tag
		$args['smallest'] = 8; //smallest tag
		return $args;

	}
}
add_filter( 'widget_tag_cloud_args', 'metz_defaultTagCloud' );
/* */

/* Social Icons */
if ( !function_exists( 'metz_placeSocialIcons' ) ) {
	function metz_placeSocialIcons() {

		$brnhmbx_social_accounts = array(
			get_theme_mod( 'brnhmbx_social_Facebook' ),
			get_theme_mod( 'brnhmbx_social_Twitter' ),
			get_theme_mod( 'brnhmbx_social_Instagram' ),
			get_theme_mod( 'brnhmbx_social_Pinterest' ),
			get_theme_mod( 'brnhmbx_social_Google' ),
			get_theme_mod( 'brnhmbx_social_Tumblr' ),
			get_theme_mod( 'brnhmbx_social_Flickr' ),
			get_theme_mod( 'brnhmbx_social_Digg' ),
			get_theme_mod( 'brnhmbx_social_LinkedIn' ),
			get_theme_mod( 'brnhmbx_social_Vimeo' ),
			get_theme_mod( 'brnhmbx_social_YouTube' ),
			get_theme_mod( 'brnhmbx_social_Behance' ),
			get_theme_mod( 'brnhmbx_social_Dribble' ),
			get_theme_mod( 'brnhmbx_social_DeviantArt' ),
			get_theme_mod( 'brnhmbx_social_Github' ),
			get_theme_mod( 'brnhmbx_social_Bloglovin' ),
			get_theme_mod( 'brnhmbx_social_Lastfm' ),
			get_theme_mod( 'brnhmbx_social_SoundCloud' ),
			get_theme_mod( 'brnhmbx_social_VK' )
		);

		$brnhmbx_social_faIcons = array(
			'fa-facebook-square',
			'fa-twitter',
			'fa-instagram',
			'fa-pinterest-square',
			'fa-google-plus-square',
			'fa-tumblr-square',
			'fa-flickr',
			'fa-digg',
			'fa-linkedin',
			'fa-vimeo-square',
			'fa-youtube',
			'fa-behance-square',
			'fa-dribbble',
			'fa-deviantart',
			'fa-github',
			'fa-heart',
			'fa-lastfm',
			'fa-soundcloud',
			'fa-vk'
		);

		$brnhmbx_social_show = false;
		$brnhmbx_social_html = '<div class="fs14 social-accounts clearfix">';

		foreach ( $brnhmbx_social_accounts as $key => $sa ) {

			if ( $sa != 'http://' && $sa != '' ) {

				$brnhmbx_social_show = true;
				$brnhmbx_social_html .= '<a class="social-icon-touch" href="' . esc_url( $sa ) . '" target="_blank"><i class="fa ' . esc_attr( $brnhmbx_social_faIcons[$key] ) . '"></i></a>';

			}

		}

		$brnhmbx_social_html .= '</div>';

		if ( !$brnhmbx_social_show || !get_theme_mod( 'brnhmbx_sh_SocialAccounts', 1 ) ) { $brnhmbx_social_html = ''; }

		return $brnhmbx_social_html;

	}
}
/* */

/* Callback function if menu location is not set */
if ( !function_exists( 'metz_menuLocationEmpty' ) ) {
	function metz_menuLocationEmpty() {

		echo '<div class="h60"></div>';

	}
}
/* */

/* "Show Blog Posts" Feature for Slider // Since v.1.2 */
if ( !function_exists( 'metz_blogPostsToSlider' ) ) {
	function metz_blogPostsToSlider() {

		global $brnhmbx_woo_plugin;
		$category = get_theme_mod( 'brnhmbx_sliderCategory', '' );

		if ( $category ) {

			$loop_args = array(

				'showposts' => get_theme_mod( 'brnhmbx_bptsNumber', '5' ),
				'category_name' => $category,
				'ignore_sticky_posts' => 1

			);

		} else {

			$loop_args = array(

				'showposts' => get_theme_mod( 'brnhmbx_bptsNumber', '5' ),
				'ignore_sticky_posts' => 1

			);

		}

		$wp_query = new WP_Query( $loop_args );
		$slides = array();

		$pager_padding = 20;
		$brnhmbx_opt_bxControls = get_theme_mod( 'brnhmbx_opt_bxControls_Main', 'arrow' );
		$brnhmbx_sliderHeight = get_theme_mod( 'brnhmbx_sliderHeight', 500 );

		if ( ( $brnhmbx_opt_bxControls == 'bullet' || $brnhmbx_opt_bxControls == 'both' ) ) {

			$pager_padding = 40;

		}

		$brnhmbx_tra_ReadMore = esc_html__( 'READ MORE', 'metz' );

		if ( get_theme_mod( 'metz_ignorePot', 1 ) ) {

			$brnhmbx_tra_ReadMore = get_theme_mod( 'brnhmbx_tra_ReadMore', 'READ MORE' );

		}

		if ( $wp_query->have_posts() ) {

			while ( $wp_query->have_posts() ) {

				$wp_query->the_post();
				$img_path = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'slider-image' );
				$url = get_the_permalink();
				$caption_text = get_the_excerpt();
				$button_text = $brnhmbx_tra_ReadMore;
				$button_target = '_self';
				$padding_button = 'padding-top: 11px;';
				$button = '';
				$caption = '';
				$header = '';
				$padding_if_not_empty = '';
				$padding_caption = '';
				$slide_image = '';

				if ( $img_path ) {

					$slide_image = $img_path[0];

				} else {

					$slide_image = get_template_directory_uri() . '/css/images/image-placeholder.jpg';

				}

				if ( get_the_title() ) {

					$header = '<div class="playfair slider-header">' . esc_attr( get_the_title() ) . '</div>';
					$padding_caption = 'padding-top: 20px;';

				}

				if ( $caption_text ) {

					$caption = '<div class="playfair fs16 slider-caption" style="' . esc_attr( $padding_caption ) . '">' . wp_kses_post( $caption_text ) . '</div>';
				}

				if ( $header || $caption ) {

					$padding_button = 'padding-top: 35px;';

				}

				if ($url != '' && $url != 'http://') {

					$button = '<div class="bButton montserrat slider-button" style="' . esc_attr( $padding_button ) . ' line-height: 30px;"><a href="' . esc_url( $url ) . '" target="' . esc_attr( $button_target ) . '">' . wp_kses_post( $button_text ) . '</a></div>';
				}

				if ( $button || $caption || $header ) {

					$padding_if_not_empty = 'padding: 35px 80px 35px 80px; ';

				}

				if ( get_theme_mod( 'brnhmbx_bptsDate', 0 ) ) {

					$date = '<div class="slider-date montserrat fs11" style="padding-bottom: 5px;">' . get_the_date() . '</div>';

				} else {

					$date = '';

				}

				$slides[] = '
				<li><div class="slide-container" style="background-image: url(' . esc_url( $slide_image ) . '); height: ' . esc_attr( $brnhmbx_sliderHeight ) . 'px;">
					<div class="slide-info-outer">
	                    <div class="slide-info">
	                        <div class="slide-info-inner">
								<div class="slide-text" style="' . esc_attr( $padding_if_not_empty ) . '">' . wp_kses_post( $date ) . wp_kses_post( $header ) . wp_kses_post( $caption ) . wp_kses_post( $button ) . '</div>
	                        </div>
	                    </div>
	                </div>
				</div></li>';

			}

		}

		wp_reset_postdata();

		$bpts = '<div class="metz-slider-container" style="padding-bottom: ' . esc_attr( $pager_padding ) . 'px;"><ul class="bxslider-main" style="overflow: hidden; height: ' . esc_attr( $brnhmbx_sliderHeight ) . 'px;">' . implode( '', $slides ) . '</ul></div>';

		if ( $brnhmbx_woo_plugin && function_exists( 'is_woocommerce' ) && is_woocommerce() ) {

			//Hide Slider

		} else {

			if ( get_theme_mod( 'brnhmbx_bpts', '0' ) ) {

				if ( is_home() ) {

					if ( get_theme_mod( 'brnhmbx_opt_SliderHomeView', 'home-all' ) == 'home-all' ) {

						echo wp_kses_post( $bpts );

					} else if ( get_theme_mod( 'brnhmbx_opt_SliderHomeView', 'home-all' ) == 'home-front' && get_query_var( 'paged' ) <= 1 ) {

						echo wp_kses_post( $bpts );

					} else if ( get_theme_mod( 'brnhmbx_opt_SliderHomeView', 'home-all' ) == 'home-hide' ) {

						//Hide Slider

					}

				}

				if ( is_archive() && get_theme_mod( 'brnhmbx_sh_SliderArchive', 0 ) ) {

					echo wp_kses_post( $bpts );

				}

				if ( is_single() && get_theme_mod( 'brnhmbx_sh_SliderPost', 0 ) ) {

					echo wp_kses_post( $bpts );

				}

			}

		}

	}
}
/* */

/* Exclude posts when "Show Blog Posts in Slider" is chosen // Since v.1.6 */
if ( !function_exists( 'metz_excludePostsUsedInSlider' ) ) {
	function metz_excludePostsUsedInSlider() {

		$category = get_theme_mod( 'brnhmbx_sliderCategory', '' );

		if ( $category ) {

			$loop_args = array(

				'showposts' => get_theme_mod( 'brnhmbx_bptsNumber', '5' ),
				'category_name' => $category,
				'ignore_sticky_posts' => 1

			);

		} else {

			$loop_args = array(

				'showposts' => get_theme_mod( 'brnhmbx_bptsNumber', '5' ),
				'ignore_sticky_posts' => 1

			);

		}

		$wp_query = new WP_Query( $loop_args );
		$excludePostIDs = array();

		if ( $wp_query->have_posts() ) {

			while ( $wp_query->have_posts() ) {

				$wp_query->the_post();
				array_push( $excludePostIDs, get_the_ID() );

			}

		}

		wp_reset_postdata();

		return $excludePostIDs;

	}
}
/* */

/* Author Box */
if ( !function_exists( 'metz_author_box' ) ) {
	function metz_author_box() {

		global $post;

		if ( is_single() && isset( $post->post_author ) ) {

			$display_name = get_the_author_meta( 'display_name', $post->post_author );

			if ( !$display_name ) {

				$display_name = get_the_author_meta( 'nickname', $post->post_author );

			}

			$user_description = get_the_author_meta( 'user_description', $post->post_author );
			$user_website = get_the_author_meta( 'url', $post->post_author );
			$user_posts = get_author_posts_url( get_the_author_meta( 'ID' , $post->post_author ) );

			$author_details = '<div class="author-avatar playfair clearfix">' . get_avatar( get_the_author_meta( 'user_email' ) , 40 ) . '<em>' . esc_attr( get_theme_mod( 'brnhmbx_metz_tra_About', 'about' ) ) . '</em> <a href="'. esc_url( $user_posts ) .'">' . esc_html( $display_name ) . '</a></div>';

			if ( $user_description ) {

				$author_details .= '<div class="author-bio arial fs14">' . wp_kses_post( $user_description ) . '</div>';

			}

			$author_details .= '<div class="author-links author-all-posts"><i class="fa fa-list tagicon i-spcr-r2"></i><a href="'. esc_url( $user_posts ) .'">' . esc_attr( get_theme_mod( 'brnhmbx_metz_tra_AllByAuthor', 'View All Posts by Author' ) ) . '</a></div>';

			if ( $user_website ) {

				$author_details .= '<div class="author-links author-website"><i class="fa fa-link tagicon i-spcr-r2"></i><a href="' . esc_url( $user_website ) .'" target="_blank" rel="nofollow">' . esc_attr( get_theme_mod( 'brnhmbx_metz_tra_AuthorWebsite', 'Visit Author Website' ) ) . '</a></div>';

			}

			$content = '<div class="author-box-outer zig-zag clearfix montserrat"><div class="author-box' . metz_applyLayout() . '">' . wp_kses_post( $author_details ) . '</div></div>';

		}

		return $content;

	}
}

/* Enqueue Gutenberg editor styles */
if ( !function_exists( 'metz_gutenberg_styles' ) ) {
	function metz_gutenberg_styles() {

		wp_enqueue_style( 'metz-fonts', metz_fonts_url(), array(), null );
		wp_enqueue_style( 'metz-gutenberg', get_template_directory_uri() . '/css/gutenberg-editor.css', false, '@@pkg.version', 'all' );
		wp_add_inline_style( 'metz-gutenberg', metz_rewrite_gutenberg_editor_css() );

	}
}
add_action( 'enqueue_block_editor_assets', 'metz_gutenberg_styles' );
/* */

/* Include the TGM_Plugin_Activation class. */
require_once dirname( __FILE__ ) . '/lib/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'metz_register_required_plugins' );

if ( !function_exists( 'metz_register_required_plugins' ) ) {
	function metz_register_required_plugins() {

	    $plugins = array(

				array(
					'name' => 'Widget Importer & Exporter',
					'slug' => 'widget-importer-exporter',
					'required' => false
				),

				array(
					'name' => 'Metz Components',
					'slug' => 'metz-components',
					'source' => get_template_directory() . '/lib/plugins/metz-components.zip',
					'required' => false,
				),

				array(
					'name' => 'New Metz Slider',
					'slug' => 'new-metz-slider',
					'source' => get_template_directory_uri() . '/lib/plugins/new-metz-slider.zip',
					'required' => false,
				),

	      array(
	      	'name'      => 'Instagram Feed',
	      	'slug'      => 'instagram-feed',
	      	'required'  => false,
	      ),

				array(
					'name'      => 'Contact Form 7',
					'slug'      => 'contact-form-7',
					'required'  => false
				)

	    );

		$config = array(
			'id'           => 'metz',                // Unique ID for hashing notices for multiple instances of TGMPA.
			'default_path' => '',                      // Default absolute path to bundled plugins.
			'menu'         => 'tgmpa-install-plugins', // Menu slug.
			'has_notices'  => true,                    // Show admin notices or not.
			'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
			'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic' => false,                   // Automatically activate plugins after installation or not.
			'message'      => '',                      // Message to output right before the plugins table.

		);

	    tgmpa( $plugins, $config );

	}
}
/* */

/* Output Customize CSS */
if ( !function_exists( 'metz_rewriteCSS' ) ) {
	function metz_rewriteCSS() {

		$metz2017_font_primary = get_theme_mod( 'metz2017_font_primary', 'Playfair_Display' );
		$metz2017_font_secondary = get_theme_mod( 'metz2017_font_secondary', 'Arial' );

		$brnhmbx_color_Standard_Background = get_theme_mod( 'brnhmbx_color_Standard_Background', '#FFF' );
		$brnhmbx_color_Standard_Border = get_theme_mod( 'brnhmbx_color_Standard_Border', '#CCC' );
		$brnhmbx_borderWidth_Standard = get_theme_mod( 'brnhmbx_borderWidth_Standard', '0' );
		$brnhmbx_color_Standard_DCB = get_theme_mod( 'brnhmbx_color_Standard_DCB', '#999' );
		$brnhmbx_color_Standard_Header = get_theme_mod( 'brnhmbx_color_Standard_Header', '#000' );
		$brnhmbx_color_Standard_RMBo = get_theme_mod( 'brnhmbx_color_Standard_RMBo', '#000' );
		$brnhmbx_color_Standard_RMB = get_theme_mod( 'brnhmbx_color_Standard_RMB', '#FFF' );
		$brnhmbx_color_Standard_RMT = get_theme_mod( 'brnhmbx_color_Standard_RMT', '#000' );
		$brnhmbx_color_Standard_Content = get_theme_mod( 'brnhmbx_color_Standard_Content', '#666' );
		$brnhmbx_color_Standard_Social = get_theme_mod( 'brnhmbx_color_Standard_Social', '#d5b977' );
		$brnhmbx_color_Standard_Link = get_theme_mod( 'brnhmbx_color_Standard_Link', '#9b7d16' );
		$brnhmbx_color_Standard_InputBackground = get_theme_mod( 'brnhmbx_color_Standard_InputBackground', '#f3f3f3' );
		$brnhmbx_color_Standard_InputText = get_theme_mod( 'brnhmbx_color_Standard_InputText', '#999' );
		$brnhmbx_color_Standard_BotSdw = get_theme_mod( 'brnhmbx_color_Standard_BotSdw', '#dadada' );
		$brnhmbx_color_Standard_PostNavBackground = get_theme_mod( 'brnhmbx_color_Standard_PostNavBackground', '#000' );
		$brnhmbx_color_Standard_PostNavLink = get_theme_mod( 'brnhmbx_color_Standard_PostNavLink', '#FFF' );
		$brnhmbx_color_Standard_Teaser = get_theme_mod( 'brnhmbx_color_Standard_Teaser', '#000' );

			/* General */

			$metz_css = '

			body { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Background', '#f0eeee' ) ) . '; }
			abbr, pre { background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . '; }
			abbr.required { background: transparent; }
			table, th, td, pre { border-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . '; }

			';

			if ( get_theme_mod( 'brnhmbx_upload_Background' ) ) {

				$metz_css .= '

				body { background: url(' . esc_url( get_theme_mod( 'brnhmbx_upload_Background' ) ) . ')';
				if ( get_theme_mod( 'brnhmbx_centerBackground', 1 ) ) { $metz_css .= ' top;'; }
				if ( !get_theme_mod( 'brnhmbx_centerBackground' ) ) { $metz_css .= ' ' . esc_attr( get_theme_mod( 'brnhmbx_repeatBackground', 'no-repeat' ) ); }
				$metz_css .= ' }';

			}

			if ( get_theme_mod( 'brnhmbx_opt_PageWidth', 1080 ) == '1080' ) {

				$metz_css .= '

				.main-container-outer,
				.header-widgets-container { max-width: 1120px; }
				.leaderboard-inner { max-width: 1080px; }

				';

			}

			/* Misc */

			$metz_css .= '

			.filter-bar { background-color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . '; }
			.filter-bar-content { color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; }
			.nothing-found { background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . '; }
			.page-with-no-image { color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . '; }
			#googleMap { height: ' . esc_attr( get_theme_mod( 'brnhmbx_mapHeight', 500 ) ) . 'px; }
			.leaderboard-inner,
			.leaderboard-inner-afs { background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; }

			';

			/* Post Formats */

			if ( get_theme_mod( 'brnhmbx_opt_GalleryPos_Gallery', 'content' ) == 'iof' && has_post_format( 'gallery' ) ) {

				$metz_css .= '

				.gallery,
				.tiled-gallery,
				.jetpack-slideshow { display: none; }

				';

			}

			$metz_css .= '

			.author-box-outer { background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_Content ) . '; }
			.author-box-outer a,
			.author-box-outer a:visited { opacity: 1; color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; }
			.author-links a,
			.author-links a:visited { opacity: 1; color: ' . esc_attr( $brnhmbx_color_Standard_DCB ) . '; }

			article.post { background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; border-color: ' . esc_attr( $brnhmbx_color_Standard_Border ) . '; border-width: ' . esc_attr( $brnhmbx_borderWidth_Standard ) . 'px; }
			article .wp-caption p.wp-caption-text { background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; }
			article.post .tag-bar,
			article.post .paging-bar,
			article.post .category-bar,
			article.post .tag-bar a,
			article.post .tag-bar a:visited,
			article.post .category-bar a,
			article.post .category-bar a:visited,
			article.post blockquote,
			.wpcf7-form-control-wrap span,
			.wpcf7-form p,
			.wpcf7-response-output,
			.wpcf7-mail-sent-ok { color: ' . esc_attr( $brnhmbx_color_Standard_DCB ) . '; }
			article.post .chief-hdr,
			article.post .chief-hdr a,
			article.post .chief-hdr a:visited,
			article.post .date-bar,
			article.post .date-bar a,
			article.post .date-bar a:visited { color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . '; }
			.bx-wrapper .bx-pager.bx-default-pager a,
			.bx-wrapper .bx-pager.bx-default-pager a:hover,
			.bx-wrapper .bx-pager.bx-default-pager a.active { background-color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . '; }
			article.post .author-bar,
			article.post div.the-content { color: ' . esc_attr( $brnhmbx_color_Standard_Content ) . '; }
			article.post .social-bar a,
			article.post .social-bar a:visited { color: ' . esc_attr( $brnhmbx_color_Standard_Social ) . '; }
			article.post blockquote { border-left-color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; }
			article.post .the-content a,
			article.post .the-content a:visited,
			article.post .paging-bar a,
			article.post .paging-bar a:visited,
			var,
			.wpcf7-form .wpcf7-submit { color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; }
			.wpcf7-form .wpcf7-submit:hover { color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; background-color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; border-color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; }
			.excerpt-teaser { color: ' . esc_attr( $brnhmbx_color_Standard_Teaser ) . '; }
			article.post .author-bar a,
			article.post .author-bar a:visited { color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; border-bottom: 1px solid; border-bottom-color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; }
			article.post .btnReadMore a,
			article.post .btnReadMore a:visited { background-color: ' . esc_attr( $brnhmbx_color_Standard_RMB ) . '; border-color: ' . esc_attr( $brnhmbx_color_Standard_RMBo ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . '; }
			article.post .btnReadMore a:hover { background-color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_RMB ) . '; }
			article.post .post-styleB a,
			article.post .post-styleB a:visited { color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . '; }
			input,
			textarea,
			select,
			.social-bg { background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_InputText ) . '; }
			article.post hr { background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . '; }
			article.post a.date-a,
			article.post a.date-a:visited { color: ' . esc_attr( $brnhmbx_color_Standard_DCB ) . '; }
			.social-bar { border: 1px solid ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . '; }
			a .page-navi-btn,
			a .page-navi-btn:visited { background-color: ' . esc_attr( $brnhmbx_color_Standard_PostNavBackground ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_PostNavLink ) . '; }
			a .page-navi-btn:hover { background-color: ' . esc_attr( $brnhmbx_color_Standard_PostNavLink ) . '; color: ' . esc_attr( $brnhmbx_color_Standard_PostNavBackground ) . '; }
			span.page-numbers.dots,
			span.page-numbers.current,
			.pagenavi a.page-numbers,
			.pagenavi a.page-numbers:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Site_PageNumbers', '#000' ) ) . '; }
			.pagenavi a.next.page-numbers,
			.pagenavi a.prev.page-numbers { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Site_RMB', '#000' ) ) . '; border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Site_RMBo', '#000' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Site_RMT', '#FFF' ) ) . '; }
			.pagenavi a.next.page-numbers:hover,
			.pagenavi a.prev.page-numbers:hover { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Site_RMT', '#FFF' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Site_RMB', '#000' ) ) . '; }

			';

			if ( is_home() || is_archive() ) {

				$metz_css .= '

				.article-inner { max-width: 720px; }

				';

			}

			if ( get_theme_mod( 'brnhmbx_sh_BotSdw', 1 ) ) {

				$metz_css .= '

				.zig-zag:after {
					background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Standard_BotSdw', '#dadada' ) ) . ';
					display: block;
					bottom: 0px;
					left: 0px;
					width: 100%;
					height: 1px;
				}

				.comments-container.zig-zag:after {
					background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_BotSdw', '#dadada' ) ) . ';
				}

				';

			}

			/* Related Posts & Post Comments */

			$metz_css .= '

			.comments-container { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_Background', '#FFF' ) ) . '; }
			.comments { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_Content', '#666' ) ) . '; }
			.comment-reply-title,
			.comments .comments-hdr,
			.comment-author-name { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_Header', '#000' ) ) . '; }
			.rp-a-without-image { background: rgba(' . esc_attr( metz_hex2rgb( get_theme_mod( 'brnhmbx_color_RP_Box', '#ebe4ca' ) ) ) . ',' . esc_attr( get_theme_mod( 'brnhmbx_rng_RP_Box', '100' ) / 100 ) . '); }
			.related-posts a > div.related-post-item-header-a .rpih-inner-a,
			.related-posts a:visited > div.related-post-item-header-a .rpih-inner-a,
			.related-posts a > div.related-post-item-header-b .rpih-inner-b,
			.related-posts a:visited > div.related-post-item-header-b .rpih-inner-b { background: rgba(' . esc_attr( metz_hex2rgb( get_theme_mod( 'brnhmbx_color_RP_Box', '#ebe4ca' ) ) ) . ',' . esc_attr( get_theme_mod( 'brnhmbx_rng_RP_Box', '100' ) / 100 ) . '); color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_RP_Text', '#756c4c' ) ) . '; }
			.related-posts a:hover > div.related-post-item-header-a .rpih-inner-a,
			.related-posts a:hover > div.related-post-item-header-b .rpih-inner-b { background: rgba(' . esc_attr( metz_hex2rgb( get_theme_mod( 'brnhmbx_color_RP_Text', '#756c4c' ) ) ) . ', 1' . '); color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_RP_Box', '#ebe4ca' ) ) . '; }
			.comments .comment-text { border-top: 1px solid ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_Liner', '#e3e3e3' ) ) . '; }
			.form-submit .submit,
			.comments a,
			.comments a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_Link', '#9b7d16' ) ) . '; }
			.comments-paging .page-numbers.current,
			.comment-date,
			.comment-awaiting,
			.must-log-in,
			.logged-in-as,
			.comment-input-hdr,
			.comments-num { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_DPL', '#999' ) ) . '; }
			.comments input,
			.comments textarea,
			.comments select { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_InputBackground', '#f3f3f3' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_InputText', '#999' ) ) . '; }
			.comment-content span.bButton a,
			.comment-content span.bButton a:visited,
			.comment-respond .form-submit .submit { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_RMB', '#FFF' ) ) . '; border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_RMBo', '#000' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_RMT', '#000' ) ) . '; }
			.comment-content span.bButton a:hover,
			.comment-respond .form-submit .submit:hover { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_RMT', '#000' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_PC_RMB', '#FFF' ) ) . '; }

			';

			/* Menu & Header */

			$metz_css .= '

			.slicknav_menu,
			#sticky-menu-container { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Menu_Background', '#000' ) ) . '; }
			.slicknav_menu .slicknav_icon-bar { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_MenuLink', '#FFF' ) ) . '; }
			.slicknav_menu a,
			.slicknav_menu a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_MenuLink', '#FFF' ) ) . '; }
			.slicknav_menu a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_MenuLink_Hover', '#6fc4d4' ) ) . '; }

			.logo-text a,
			.logo-text a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Logo', '#FFF' ) ) . '; }

			.header-menu-outer { margin-bottom: ';
			if ( get_theme_mod( 'brnhmbx_sh_SocialAccounts', 1 ) && get_theme_mod( 'brnhmbx_sh_HeaderSocial', 1 ) ) { $metz_css .= '10'; } else { $metz_css .= '20'; }
			$metz_css .= 'px; }
			.header-menu-outer a,
			.header-menu-outer a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_HeaderLink', '#000' ) ) . '; }
			.header-menu-outer a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_HeaderLink_Hover', '#6fc4d4' ) ) . '; }

			.site-nav2 a,
			.site-nav2 a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_MenuLink', '#FFF' ) ) . '; }
			.site-nav2 a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_MenuLink_Hover', '#6fc4d4' ) ) . '; }
			.site-nav2 li ul { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_MenuLevel', '#000' ) ) . '; }

			.site-top-outer { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Menu_Background', '#000' ) ) . '; padding: 0 40px 0 40px; }
			.site-logo-container img { display: block; }

			';

			if ( get_theme_mod( 'brnhmbx_opt_MenuPos', 'logo-top' ) == 'logo-left' ) { //START brnhmbx_opt_MenuPos

			$metz_css .= '

			.site-logo-outer { ';

			if ( get_theme_mod( 'brnhmbx_upload_Logo' ) ) { $metz_css .= 'font-size: 0; '; }

			$metz_css .= '}

			.site-logo-container { display: inline-block; padding: 40px 0 0 0; }
			.site-menu-outer { display: none; }

			@media all and (min-width: 1000px) {

				.site-top-container { display: table; }
				.site-logo-outer { display: table-cell; vertical-align: middle; }
				.site-logo-container { padding: 0; }
				.site-menu-outer { display: table-cell; vertical-align: middle; width: 100%; }

			}

			';

			} else if ( get_theme_mod( 'brnhmbx_opt_MenuPos', 'logo-top' ) == 'logo-top' ) {

			$metz_css .= '

			.site-logo-outer { ';
			if ( get_theme_mod( 'brnhmbx_upload_Logo' ) ) { $metz_css .= 'font-size: 0; '; }
			$metz_css .= 'padding-top: 40px; padding-bottom: 0; }
			.site-logo-container { display: inline-block; }
			.site-menu-outer { display: none; }
			.site-menu-container { display: inline-block; }

			@media all and (min-width: 1000px) {

				.site-logo-outer { padding-top: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingTop', '40' ) ) . 'px; padding-bottom: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingBottom', '0' ) ) . 'px; }
				.site-menu-outer { width: 100%; font-size: 0; display: block; }

			}

			';

			} else if ( get_theme_mod( 'brnhmbx_opt_MenuPos', 'logo-top' ) == 'logo-bottom' ) {

			$metz_css .= '

			.site-top-outer { display: none; }
			.site-logo-outer { ';
			if ( get_theme_mod( 'brnhmbx_upload_Logo' ) ) { $metz_css .= 'font-size: 0; '; }
			$metz_css .= 'padding-top: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingTop', '40' ) ) . 'px; padding-bottom: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingBottom', '0' ) + 40 ) . 'px; }
			.site-logo-container { display: inline-block; }
			.site-menu-outer { width: 100%; font-size: 0; }
			.site-menu-container { display: inline-block; }

			@media all and (min-width: 1000px) {

				.site-top-outer { display: block; }
				.site-logo-outer { padding-bottom: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingBottom', '0' ) ) . 'px; }

			}

			';

			} else if ( get_theme_mod( 'brnhmbx_opt_MenuPos', 'logo-top' ) == 'logo-very-top' ) {

			$metz_css .= '

			.site-top-outer { display: none; }
			.site-logo-outer { ';
			if ( get_theme_mod( 'brnhmbx_upload_Logo' ) ) { $metz_css .= 'font-size: 0; '; }
			$metz_css .= 'padding-top: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingTop', '40' ) ) . 'px; padding-bottom: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingBottom', '0' ) ) . 'px; }
			.site-logo-container { display: inline-block; }
			.site-menu-outer { width: 100%; font-size: 0; }
			.site-menu-container { display: inline-block; }

			@media all and (min-width: 1000px) {

				.site-top-outer { display: block; }
				.site-logo-outer { padding-bottom: ' . esc_attr( get_theme_mod( 'brnhmbx_logoPaddingBottom', '0' ) ) . 'px; }

			}

			';

			} //END brnhmbx_opt_MenuPos

			if ( get_theme_mod( 'brnhmbx_opt_MenuWidth', '1080' ) == '1080' ) { //START brnhmbx_opt_MenuWidth

				$metz_css .= '

				.top-bar-outer { max-width: 1120px; }
				.leaderboard-inner-afs { max-width: 1080px; }

				';

			} else if ( get_theme_mod( 'brnhmbx_opt_MenuWidth', '1080' ) == 'full' ) {

				$metz_css .= '

				.top-bar-outer { max-width: 100%; }
				.leaderboard-inner-afs { max-width: 100%; }

				';

			} //END brnhmbx_opt_MenuWidth

			/* Slider Colors */

			$metz_css .= '

			.slider-caption { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Sli_Caption', '#000' ) ) . '; }
			.slider-button a,
			article.post .slider-button a,
			.slider-button a:visited,
			article.post .slider-button a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Sli_BT', '#FFF' ) ) . '; border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Sli_BBO', '#000' ) ) . '; background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Sli_BBG', '#000' ) ) . '; }
			article.post .slider-button a:hover,
			.slider-button a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Sli_BBG', '#000' ) ) . '; background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Sli_BT', '#FFF' ) ) . '; }
			.slide-info-inner { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Sli_Header', '#000' ) ) . '; }
			.slide-text { background: rgba(' . esc_attr( metz_hex2rgb( get_theme_mod( 'brnhmbx_color_Sli_Box', '#FFF' ) ) ) . ',' . esc_attr( get_theme_mod( 'brnhmbx_rng_Sli_Box', '50' ) / 100 ) . '); }

			';

			if ( get_theme_mod( 'brnhmbx_sliderHideMobile', 'always' ) == '320' ) {

				$metz_css .= '

				@media all and (min-width: 320px) { .metz-slider-container { display: block; } }

				';

			} else if ( get_theme_mod( 'brnhmbx_sliderHideMobile', 'always' ) == '480' ) {

				$metz_css .= '

				@media all and (min-width: 480px) { .metz-slider-container { display: block; } }

				';

			} else if ( get_theme_mod( 'brnhmbx_sliderHideMobile', 'always' ) == '640' ) {

				$metz_css .= '

				@media all and (min-width: 640px) { .metz-slider-container { display: block; } }

				';

			} else {

				$metz_css .= '

				.metz-slider-container { display: block; }

				';

			}

			/* Sidebar & Home Widgets */

			$metz_css .= '

			.widget-item,
			.textwidget { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Content', '#666' ) ) . '; }
			.widget-item a,
			.widget-item a:visited,
			.textwidget a,
			.textwidget a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Link', '#9b7d16' ) ) . '; }
			.widget-item a:hover,
			.widget-item .textwidget a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_LinkHover', '#000' ) ) . '; }

			#wp-calendar { border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_InputBackground', '#f3f3f3' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Content', '#666' ) ) . '; }
			#wp-calendar caption { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_InputBackground', '#f3f3f3' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_InputText', '#999' ) ) . '; }
			#wp-calendar tfoot td#prev a:hover,
			#wp-calendar tfoot td#next a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_LinkHover', '#000' ) ) . '; }

			.wp-tag-cloud li a,
			.wp-tag-cloud li a:visited { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_CatsBackground', '#9bbba1' ) ) . '; border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_CatsBorder', '#9bbba1' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_CatsText', '#FFF' ) ) . '; }
			.wp-tag-cloud li a:hover { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_CatsText', '#FFF' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_CatsBackground', '#9bbba1' ) ) . '; }

			.widget-item input,
			.widget-item textarea,
			.widget-item select { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_InputBackground', '#f3f3f3' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_InputText', '#999' ) ) . '; }

			.widget-item abbr { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_InputBackground', '#f3f3f3' ) ) . '; }

			.widget-item h2,
			.widget-date-bar,
			.widget-date-bar a,
			.widget-date-bar a:visited,
			.recent-comment-author { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Title', '#000' ) ) . '; }

			.widget-item-opt-hdr,
			.widget-date-bar a.date-a,
			.recent-comment-hdr a,
			.recent-comment-hdr a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_OptHdr', '#999' ) ) . '; }
			.recent-comment-item { border-bottom-color: rgba(' . esc_attr( metz_hex2rgb( get_theme_mod( 'brnhmbx_color_W_OptHdr', '#999' ) ) ) . ', 0.2); }
			.widget-item { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Background', '#FFF' ) ) . '; }

			.widget-item.zig-zag:after { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_BotSdw', '#dadada' ) ) . '; }

			.woo-p-widget-inner a { color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . ' !important; }

			';

			/* Footer */

			$metz_css .= '

			.footer-box { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_Background', '#000' ) ) . '; }
			.footer-text { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_Content', '#000' ) ) . '; }
			.site-footer a,
			.site-footer a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_Link', '#000' ) ) . '; }
			.site-footer a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_Link_Hover', '#6fc4d4' ) ) . '; }

			a.a-top,
			a.a-top:visited { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_BTT_BG', '#000' ) ) . '; border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_BTT_BO', '#FFF' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_BTT_T', '#FFF' ) ) . '; }
			a.a-top:hover { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_BTT_T', '#FFF' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_Footer_BTT_BG', '#000' ) ) . '; }

			.widget-item-footer,
			.widget-item-footer .textwidget { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_Content', '#e5ecee' ) ) . '; }
			.widget-item-footer a,
			.widget-item-footer a:visited,
			.widget-item-footer .textwidget a,
			.widget-item-footer .textwidget a:visited { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_Link', '#6fc4d4' ) ) . '; }
			.widget-item-footer a:hover,
			.widget-item-footer .textwidget a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_LinkHover', '#FFF' ) ) . '; }

			.widget-item-footer #wp-calendar { border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_InputBackground', '#f3f3f3' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_Content', '#e5ecee' ) ) . '; }
			.widget-item-footer #wp-calendar caption { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_InputBackground', '#f3f3f3' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_InputText', '#999' ) ) . '; }
			.widget-item-footer #wp-calendar tfoot td#prev a:hover,
			.widget-item-footer #wp-calendar tfoot td#next a:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_LinkHover', '#FFF' ) ) . '; }

			.widget-item-footer .wp-tag-cloud li a,
			.widget-item-footer .wp-tag-cloud li a:visited { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_CatsBackground', '#e5ecee' ) ) . '; border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_CatsBorder', '#e5ecee' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_CatsText', '#57818d' ) ) . '; }
			.widget-item-footer .wp-tag-cloud li a:hover { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_CatsText', '#57818d' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_CatsBackground', '#e5ecee' ) ) . '; }

			.widget-item-footer input,
			.widget-item-footer textarea,
			.widget-item-footer select { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_InputBackground', '#f3f3f3' ) ) . '; color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_InputText', '#999' ) ) . '; }

			.widget-item-footer abbr { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_InputBackground', '#f3f3f3' ) ) . '; }

			.widget-item-footer h2,
			.widget-item-footer .widget-date-bar,
			.widget-item-footer .widget-date-bar a,
			.widget-item-footer .widget-date-bar a:visited,
			.widget-item-footer .recent-comment-author { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_Title', '#FFF' ) ) . '; }

			.widget-item-footer .widget-item-opt-hdr,
			.widget-item-footer .widget-date-bar a.date-a,
			.widget-item-footer .recent-comment-hdr a,
			.widget-item-footer .recent-comment-hdr a { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_OptHdr', '#999' ) ) . '; }
			.widget-item-footer .recent-comment-item { border-bottom-color: rgba(' . esc_attr( metz_hex2rgb( get_theme_mod( 'brnhmbx_color_WF_OptHdr', '#999' ) ) ) . ', 0.2); }
			.widget-item-footer { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_Background', '#000' ) ) . '; }

			.widget-item-footer.zig-zag:after { background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_WF_BotSdw', '#000' ) ) . '; }

			';

			if ( get_theme_mod( 'brnhmbx_opt_FooterWidth', '1080' ) == '1080' ) { //START brnhmbx_opt_FooterWidth

				$metz_css .= '

				.site-footer { max-width: 1120px; }

				';

			} else if ( get_theme_mod( 'brnhmbx_opt_FooterWidth', '1080' ) == 'full' ) {

				$metz_css .= '

				.site-footer { max-width: 100%; }

				';

			} //END brnhmbx_opt_FooterWidth

			/* Fonts */

			foreach ( metz_font_labels() as $key => $val ) {
				$add_underscore = str_replace( ' ', '_', $key );
				if ( $add_underscore == $metz2017_font_primary ) { $font_primary = 'font-family: "' . wp_kses_post( $key ) . '", ' . wp_kses_post( $val ) . ';'; }
				if ( $add_underscore == $metz2017_font_secondary ) { $font_secondary = 'font-family: "' . wp_kses_post( $key ) . '", ' . wp_kses_post( $val ) . ';'; }
			}

			$metz_css .= '

			.playfair,
			blockquote,
			.comment-reply-title,
			.brnhmbx-wc-outer h1,
			.brnhmbx-wc-outer h2,
			.brnhmbx-wc-outer h3,
			.products li a h3,
			.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta strong[itemprop="author"] { ' . wp_kses_post( $font_primary ) . ' }

			.arial,
			input,
			textarea,
			select,
			.subscribe-label,
			.mc4wp-checkbox-comment_form label,
			.brnhmbx-wc-outer,
			input.select2-input,
			.select2-results,
			.select2-results .select2-highlighted,
			p.comment-form-cookies-consent label[for="wp-comment-cookies-consent"] { ' . wp_kses_post( $font_secondary ) . ' }

			';

			/* UPPERCASE */

			if ( get_theme_mod( 'brnhmbx_Uppercase', '1' ) ) {

			$metz_css .= '

			.wp-tag-cloud li,
			.social-widget-button-text,
			.date-bar,
			.tag-bar,
			.category-bar,
			.widget-date-bar,
			.widget-date-bar-b,
			.comment-date,
			.post-password-form input[type="submit"],
			.filter-bar-content,
			a.woocommerce-review-link,
			a.woocommerce-review-link:visited,
			.woocommerce-result-count,
			.button.add_to_cart_button.product_type_variable,
			.button.add_to_cart_button.product_type_simple,
			button.single_add_to_cart_button.button.alt,
			.woocommerce .woocommerce-message a.button,
			.woocommerce .woocommerce-message a.button:visited,
			.woocommerce #review_form #respond .form-submit input.submit,
			ul.products li a.added_to_cart.wc-forward,
			.woocommerce #respond input#submit,
			.woocommerce a.button,
			.woocommerce button.button,
			.woocommerce input.button,
			.posted_in a,
			.posted_in a:visited,
			.tagged_as a,
			.tagged_as a:visited,
			.woocommerce span.onsale,
			.woocommerce a.reset_variations,
			.woocommerce a.reset_variations:visited,
			.woocommerce a.shipping-calculator-button,
			.woocommerce a.shipping-calculator-button:visited,
			.woocommerce a.woocommerce-remove-coupon,
			.woocommerce a.woocommerce-remove-coupon:visited,
			p.stock.out-of-stock,
			p.stock.in-stock,
			.woocommerce a.edit,
			.woocommerce a.edit:visited,
			div.price_slider_amount button,
			.woocommerce div.product .woocommerce-tabs ul.tabs li,
			.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta time[itemprop="datePublished"],
			.woocommerce #respond label,
			.woocommerce p.form-row label,
			.woo-p-widget a.added_to_cart.wc-forward,
			.woo-p-widget .product_type_simple,
			.mc4wp-checkbox-registration_form label,
			.slider-date,
			.author-links { text-transform: uppercase; }

			';

			}

			/* Woo Commerce */

			$metz_css .= '

			.brnhmbx-wc-outer {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . ';
				color: ' . esc_attr( $brnhmbx_color_Standard_Content ) . ';
			}

			.brnhmbx-wc-outer h1,
			.brnhmbx-wc-outer h2,
			.brnhmbx-wc-outer h3,
			.star-rating,
			p.stars span a,
			.amount,
			.price ins,
			.products li a h3,
			.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta strong[itemprop="author"] {
				color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . ';
			}

			a.woocommerce-review-link,
			a.woocommerce-review-link:visited,
			.woocommerce-result-count {
				color: ' . esc_attr( $brnhmbx_color_Standard_DCB ) . ';
			}

			.woocommerce .woocommerce-error,
			.woocommerce .woocommerce-info,
			.woocommerce .woocommerce-message {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
			}

			.button.add_to_cart_button.product_type_variable,
			.button.add_to_cart_button.product_type_simple,
			button.single_add_to_cart_button.button.alt,
			.woocommerce .woocommerce-message a.button,
			.woocommerce .woocommerce-message a.button:visited,
			.woocommerce #review_form #respond .form-submit input.submit,
			ul.products li a.added_to_cart.wc-forward,
			.woo-p-widget a.added_to_cart.wc-forward,
			.woo-p-widget .product_type_simple {
				border-color: ' . esc_attr( $brnhmbx_color_Standard_RMBo ) . ';
				background-color: ' . esc_attr( $brnhmbx_color_Standard_RMB ) . ';
				color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . ';
			}

			.woo-p-widget .product_type_simple {
				color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . ' !important;
			}

			.woocommerce #respond input#submit,
			.woocommerce a.button,
			.woocommerce button.button,
			.woocommerce input.button {
				border-color: ' . esc_attr( $brnhmbx_color_Standard_RMBo ) . ';
				background-color: ' . esc_attr( $brnhmbx_color_Standard_RMB ) . ' !important;
				color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . ' !important;
			}

			.button.add_to_cart_button.product_type_variable:hover,
			.button.add_to_cart_button.product_type_simple:hover,
			button.single_add_to_cart_button.button.alt:hover,
			.woocommerce .woocommerce-message a.button:hover,
			.woocommerce #review_form #respond .form-submit input.submit:hover,
			ul.products li a.added_to_cart.wc-forward:hover,
			.woo-p-widget a.added_to_cart.wc-forward:hover,
			.woo-p-widget .product_type_simple:hover {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . ' !important;
				color: ' . esc_attr( $brnhmbx_color_Standard_RMB ) . ' !important;
				opacity: 1;
			}

			.woocommerce #respond input#submit:hover,
			.woocommerce a.button:hover,
			.woocommerce button.button:hover,
			.woocommerce input.button:hover {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . ' !important;
				color: ' . esc_attr( $brnhmbx_color_Standard_RMB ) . ' !important;
				opacity: 1;
			}

			.price del,
			a .price del,
			.price del span.amount {
				color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . ' !important;
			}

			div.quantity input.input-text.qty.text {
				border-color: ' . esc_attr( $brnhmbx_color_Standard_RMBo ) . ';
			}

			.posted_in a,
			.posted_in a:visited,
			.tagged_as a,
			.tagged_as a:visited {
				color: ' . esc_attr( $brnhmbx_color_Standard_DCB ) . ';
			}

			.woocommerce span.onsale {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_RMT ) . ';
				color: ' . esc_attr( $brnhmbx_color_Standard_RMB ) . ';
			}

			.woocommerce a.reset_variations,
			.woocommerce a.reset_variations:visited,
			.woocommerce a.shipping-calculator-button,
			.woocommerce a.shipping-calculator-button:visited,
			.woocommerce a.woocommerce-remove-coupon,
			.woocommerce a.woocommerce-remove-coupon:visited,
			p.stock.out-of-stock,
			p.stock.in-stock,
			.woocommerce a.edit,
			.woocommerce a.edit:visited,
			div.price_slider_amount button,
			.woocommerce table.group_table a,
			#comments .woocommerce-pagination a {
				color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . ';
			}

			.woocommerce div.product .woocommerce-tabs ul.tabs:before {
				border-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
			}

			.woocommerce div.product .woocommerce-tabs ul.tabs li {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
				border-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
			}

			.woocommerce div.product .woocommerce-tabs ul.tabs li a,
			.woocommerce div.product .woocommerce-tabs ul.tabs li a:visited,
			.woocommerce div.product .woocommerce-tabs ul.tabs li a:hover {
				font-weight: normal;
				color: ' . esc_attr( $brnhmbx_color_Standard_InputText ) . ';
			}

			.woocommerce div.product .woocommerce-tabs ul.tabs li.active,
			.woocommerce div.product .woocommerce-tabs ul.tabs li.active a:hover {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . ';
				color: ' . esc_attr( $brnhmbx_color_Standard_Header ) . ';
			}

			.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta time[itemprop="datePublished"],
			.woocommerce #respond label,
			.woocommerce p.form-row label {
				color: ' . esc_attr( $brnhmbx_color_Standard_DCB ) . ';
			}

			.woocommerce #reviews #comments ol.commentlist li .comment-text div.description {
				border-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
			}

			.order-info mark {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
			}

			.select2-results {
				color: ' . esc_attr( $brnhmbx_color_Standard_Content ) . ';
			}

			.select2-results .select2-highlighted {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
				color: ' . esc_attr( $brnhmbx_color_Standard_Content ) . ';
			}

			.woocommerce-checkout #payment div.payment_box {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . ';
				color: ' . esc_attr( $brnhmbx_color_Standard_Content ) . ';
			}

			.woocommerce-checkout #payment div.payment_box:before {
				border: 12px solid ' . esc_attr( $brnhmbx_color_Standard_Background ) . ';
				border-right-color: transparent;
				border-left-color: transparent;
				border-top-color: transparent;
			}

			.woocommerce-checkout #payment{
				background: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
			}

			.woocommerce-message a {
				color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . ';
			}

			';

			/* Price Filter Widget */

			$metz_css .= '

			.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
			.woocommerce .widget_price_filter .ui-slider .ui-slider-range {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . ';
			}

			.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
				background-color: ' . esc_attr( $brnhmbx_color_Standard_InputBackground ) . ';
			}

			';

			/* Mail Chimp */

			$metz_css .= '

			.mc4wp-checkbox-registration_form label,
			.mc4wp-form label {
				color: ' . esc_attr( $brnhmbx_color_Standard_DCB ) . ';
			}

			.widget-item .mc4wp-form label {
				color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_OptHdr', '#999' ) ) . ';
			}

			.mc4wp-form input[type="submit"] { color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; }
			.mc4wp-form input[type="submit"]:hover { color: ' . esc_attr( $brnhmbx_color_Standard_Background ) . '; background-color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; border-color: ' . esc_attr( $brnhmbx_color_Standard_Link ) . '; }

			.widget-item .mc4wp-form input[type="submit"] { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Link', '#9b7d16' ) ) . '; }
			.widget-item .mc4wp-form input[type="submit"]:hover { color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Background', '#FFF' ) ) . '; background-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Link', '#9b7d16' ) ) . '; border-color: ' . esc_attr( get_theme_mod( 'brnhmbx_color_W_Link', '#9b7d16' ) ) . '; }

			';

			/* Gutenberg */

			$metz_color_Standard_Background = get_theme_mod( 'brnhmbx_color_Standard_Background', '#FFF' );
			$metz_color_Standard_Content = get_theme_mod( 'brnhmbx_color_Standard_Content', '#666' );
			$metz_color_Standard_Header = get_theme_mod( 'brnhmbx_color_Standard_Header', '#000' );
			$metz_color_Standard_DCB = get_theme_mod( 'brnhmbx_color_Standard_DCB', '#999' );
			$metz_color_Standard_Link_Hover = get_theme_mod( 'brnhmbx_color_Standard_Social', '#d5b977' );

			$metz_css .= '

			.wp-block-pullquote { border-color: ' . esc_attr( $metz_color_Standard_Link_Hover ) . '; }
			.wp-block-pullquote.is-style-default { background-color: ' . esc_attr( $metz_color_Standard_Background ) . '; }

			.wp-block-verse { ' . wp_kses_post( $font_primary ) . ' }

			.wp-block-image figcaption,
			.wp-block-embed figcaption,
			.wp-block-audio figcaption,
			.wp-block-video figcaption,
			.wp-block-latest-posts time { color: ' . esc_attr( $metz_color_Standard_DCB ) . '; }

			.wp-block-table td,
			.wp-block-separator { border-color: ' . esc_attr( $metz_color_Standard_DCB ) . '; }

			.wp-block-media-text { color: ' . esc_attr( $metz_color_Standard_Header ) . '; }

			.wp-block-verse,
			.wp-block-code,
			.wp-block-preformatted { background-color: ' . esc_attr( $metz_color_Standard_Background ) . '; color: ' . esc_attr( $metz_color_Standard_Content ) . '; }

			.wp-block-button .wp-block-button__link,
			.wp-block-file .wp-block-file__button { color: ' . esc_attr( $metz_color_Standard_Background ) . ' !important; background-color: ' . esc_attr( $metz_color_Standard_Link_Hover ) . '; }

			';

			$metz_css .= esc_attr( get_theme_mod( 'brnhmbx_text_CSS', '' ) );

	    return $metz_css;

	}
}
/* */

/* Output Gutenberg Editor Inline Styles */
if ( !function_exists( 'metz_rewrite_gutenberg_editor_css' ) ) {
	function metz_rewrite_gutenberg_editor_css() {

		$metz_color_Standard_Background = get_theme_mod( 'brnhmbx_color_Standard_Background', '#FFF' );
		$metz_color_Standard_Content = get_theme_mod( 'brnhmbx_color_Standard_Content', '#666' );
		$metz_color_Standard_Header = get_theme_mod( 'brnhmbx_color_Standard_Header', '#000' );
		$metz_color_Standard_Link = get_theme_mod( 'brnhmbx_color_Standard_Link', '#9b7d16' );
		$metz_color_Standard_Link_Hover = get_theme_mod( 'brnhmbx_color_Standard_Social', '#d5b977' );
		$metz_color_Standard_InputText = get_theme_mod( 'brnhmbx_color_Standard_InputText', '#999' );
		$metz_color_Standard_InputBackground = get_theme_mod( 'brnhmbx_color_Standard_InputBackground', '#f3f3f3' );
		$metz_color_Standard_DCB = get_theme_mod( 'brnhmbx_color_Standard_DCB', '#999' );

		$metz2017_font_primary = get_theme_mod( 'metz2017_font_primary', 'Playfair_Display' );
		$metz2017_font_secondary = get_theme_mod( 'metz2017_font_secondary', 'Arial' );

		foreach ( metz_font_labels() as $key => $val ) {
			$add_underscore = str_replace( ' ', '_', $key );
			if ( $add_underscore == $metz2017_font_primary ) { $font_primary = 'font-family: "' . wp_kses_post( $key ) . '", ' . wp_kses_post( $val ) . ';'; }
			if ( $add_underscore == $metz2017_font_secondary ) { $font_secondary = 'font-family: "' . wp_kses_post( $key ) . '", ' . wp_kses_post( $val ) . ';'; }
		}

		$gutenberg_editor_css = '

			.editor-writing-flow .editor-post-title__input {
				' . wp_kses_post( $font_primary ) . '
			}

			.editor-writing-flow,
			.editor-writing-flow textarea,
			.editor-writing-flow select,
			.editor-writing-flow input[type="text"],
			.editor-writing-flow h1,
			.editor-writing-flow h2,
			.editor-writing-flow h3,
			.editor-writing-flow h4,
			.editor-writing-flow h5,
			.editor-writing-flow h6,
			.editor-writing-flow .wp-block-cover .wp-block-cover-text,
			.editor-writing-flow .wp-block-media-text,
			.editor-writing-flow .wp-block-archives select,
			.editor-writing-flow .wp-block-categories select {
				' . wp_kses_post( $font_secondary ) . '
			}

			.editor-writing-flow .wp-block-verse pre,
			.editor-writing-flow .wp-block-quote,
			.editor-writing-flow .wp-block-pullquote,
			.editor-writing-flow .wp-block-quote .wp-block-quote__citation,
			.editor-writing-flow .wp-block-pullquote .wp-block-pullquote__citation {
				' . wp_kses_post( $font_primary ) . '
			}

			.edit-post-visual-editor { background-color: ' . esc_attr( $metz_color_Standard_Background ) . '; }
			.editor-writing-flow,
			.editor-writing-flow pre { color: ' . esc_attr( $metz_color_Standard_Content ) . '; }
			.editor-writing-flow .editor-post-title__input { color: ' . esc_attr( $metz_color_Standard_Header ) . '; }
			.editor-writing-flow h1,
			.editor-writing-flow h2,
			.editor-writing-flow h3,
			.editor-writing-flow h4,
			.editor-writing-flow h5,
			.editor-writing-flow h6 { color: ' . esc_attr( $metz_color_Standard_Content ) . '; }
			.editor-writing-flow .wp-block-image figcaption,
			.editor-writing-flow .wp-block-embed figcaption,
			.editor-writing-flow .wp-block-audio figcaption,
			.editor-writing-flow .wp-block-video figcaption,
			.editor-writing-flow .wp-block-latest-posts time,
			.editor-writing-flow .wp-block-latest-comments time { color: ' . esc_attr( $metz_color_Standard_DCB ) . '; }
			.editor-writing-flow .wp-block-quote,
			.editor-writing-flow .wp-block-quote .wp-block-quote__citation,
			.editor-writing-flow .wp-block-pullquote { color: ' . esc_attr( $metz_color_Standard_DCB ) . '; border-color: ' . esc_attr( $metz_color_Standard_Link_Hover ) . ' !important; background-color: ' . esc_attr( $metz_color_Standard_Background ) . '; }
			.editor-writing-flow .wp-block-table td,
			.editor-writing-flow .wp-block-separator { border-color: ' . esc_attr( $metz_color_Standard_DCB ) . '; }
			.editor-writing-flow .wp-block-code textarea { background-color: ' . esc_attr( $metz_color_Standard_Background ) . '; color: ' . esc_attr( $metz_color_Standard_Content ) . '; }
			.editor-writing-flow .wp-block-archives select,
			.editor-writing-flow .wp-block-categories select { background-color: ' . esc_attr( $metz_color_Standard_InputBackground ) . '; color: ' . esc_attr( $metz_color_Standard_InputText ) . '; }
			.editor-writing-flow a { color: ' . esc_attr( $metz_color_Standard_Link ) . '; }
			.editor-writing-flow a:hover { color: ' . esc_attr( $metz_color_Standard_Link_Hover ) . '; }
			.editor-writing-flow .wp-block-media-text { color: ' . esc_attr( $metz_color_Standard_Header ) . '; }
			.editor-writing-flow .wp-block-button .wp-block-button__link,
			.editor-writing-flow .wp-block-file .wp-block-file__button { color: ' . esc_attr( $metz_color_Standard_Background ) . '; background-color: ' . esc_attr( $metz_color_Standard_Link_Hover ) . '; }
			.editor-writing-flow .wp-block-verse,
			.editor-writing-flow .wp-block-code,
			.editor-writing-flow .wp-block-preformatted { border-color: ' . esc_attr( $metz_color_Standard_DCB ) . '; }

		';

		return $gutenberg_editor_css;

	}
}
/* */
